@@ -1,4 +1,4 @@
-/* Copyright (C) 2007 The SpringLobby Team. All rights reserved. */
+/* Copyright (C) 2007-2009 The SpringLobby Team. All rights reserved. */
 
 #include <wx/intl.h>
 #include <wx/stattext.h>
@@ -23,6 +23,7 @@
 #include "chatpanel.h"
 #include "utils/debug.h"
 #include "utils/conversion.h"
+#include "utils/controls.h"
 #include "uiutils.h"
 #include "hostbattledialog.h"
 #include "server.h"
@@ -35,7 +36,7 @@
 #include "battlelistfilter.h"
 #include "iconimagelist.h"
 #include "useractions.h"
-#include "settings++/custom_dialogs.h"
+#include "utils/customdialogs.h"
 
 const unsigned int BATTLELIST_COLUMNCOUNT = 10;
 
@@ -59,9 +60,8 @@ BEGIN_EVENT_TABLE( BattleListTab, wxPanel )
 END_EVENT_TABLE()
 
 
-BattleListTab::BattleListTab( wxWindow* parent, Ui& ui )
+BattleListTab::BattleListTab( wxWindow* parent )
     : wxScrolledWindow( parent, -1 ),
-    m_ui( ui ),
     m_sel_battle( 0 )
 {
 	GetAui().manager->AddPane( this, wxLEFT, _T( "battlelisttab" ) );
@@ -74,7 +74,7 @@ BattleListTab::BattleListTab( wxWindow* parent, Ui& ui )
 
 	m_battlelist_sizer = new wxBoxSizer( wxVERTICAL );
 
-	m_battle_list = new BattleListCtrl( this, m_ui );
+	m_battle_list = new BattleListCtrl( this );
 	m_battle_list->SetHighLightAction ( UserActions::ActHighlight );
 	m_battlelist_sizer->Add( m_battle_list, 1, wxALL | wxEXPAND, 5 );
 
@@ -82,7 +82,7 @@ BattleListTab::BattleListTab( wxWindow* parent, Ui& ui )
 
 	m_info_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-	m_minimap = new MapCtrl( this, 100, 0, m_ui, true, true, false, false );
+	m_minimap = new MapCtrl( this, 100, 0, true, true, false, false );
 	m_info_sizer->Add( m_minimap, 0, wxALL, 5 );
 
 	m_data_sizer = new wxFlexGridSizer( 4, 2, 0, 0 );
@@ -113,7 +113,9 @@ BattleListTab::BattleListTab( wxWindow* parent, Ui& ui )
 
 	m_info_sizer->Add( m_data_sizer, 1, wxEXPAND, 5 );
 
-	m_players = new NickListCtrl( this, false );
+	m_players = new NickListCtrl( this, false, 0, true, _T("battlelist_nicklist") );
+	int width = m_players->GetClientSize().GetWidth() - 60;
+	m_players->SetColumnWidth( 3, width );
 	m_info_sizer->Add( m_players, 1, wxALL | wxEXPAND, 5 );
 
 	m_main_sizer->Add( m_info_sizer, 0, wxEXPAND, 5 );
@@ -163,8 +165,9 @@ BattleListTab::BattleListTab( wxWindow* parent, Ui& ui )
 
 	m_filter->Hide();
 
-	this->SetSizer( m_main_sizer );
-	this->Layout();
+    SetScrollRate( SCROLL_RATE, SCROLL_RATE );
+	SetSizer( m_main_sizer );
+	Layout();
 
 	SelectBattle( 0 );
 }
@@ -176,6 +179,12 @@ BattleListTab::~BattleListTab()
 		m_filter->SaveFilterValues();
 }
 
+void BattleListTab::OnConnected()
+{
+	bool filter = sett().GetBattleFilterActivState();
+	SetFilterActiv( filter );
+}
+
 void BattleListTab::SetNumDisplayed()
 {
 	int num = m_battle_list->GetItemCount();
@@ -189,7 +198,7 @@ void BattleListTab::SelectBattle( IBattle* battle )
 	m_players->ClearUsers();
 	if ( m_sel_battle != 0 )
 	{
-		m_map_text->SetLabel( RefineMapname( m_sel_battle->GetHostMapName() ) );
+		m_map_text->SetLabel( m_sel_battle->GetHostMapName() );
 		m_mod_text->SetLabel( m_sel_battle->GetHostModName() );
 		m_players_text->SetLabel( wxString::Format( _T( "%d / %d" ), int( m_sel_battle->GetNumUsers() ) - int( m_sel_battle->GetSpectators() ), int( m_sel_battle->GetMaxPlayers() ) ) );
 		m_spec_text->SetLabel( wxString::Format( _T( "%d" ), m_sel_battle->GetSpectators() ) );
@@ -266,10 +275,10 @@ void BattleListTab::UpdateBattle( IBattle& battle )
 void BattleListTab::RemoveAllBattles()
 {
 	SelectBattle( 0 );
-	m_ui.GetServer().battles_iter->IteratorBegin();
-	while ( ! m_ui.GetServer().battles_iter->EOL() )
+	serverSelector().GetServer().battles_iter->IteratorBegin();
+	while ( ! serverSelector().GetServer().battles_iter->EOL() )
 	{
-		Battle* temp_battle = m_ui.GetServer().battles_iter->GetBattle();
+		Battle* temp_battle = serverSelector().GetServer().battles_iter->GetBattle();
 		if ( temp_battle != 0 )
 			temp_battle->SetGUIListActiv( false );
 	}
@@ -279,9 +288,9 @@ void BattleListTab::RemoveAllBattles()
 
 
 void BattleListTab::UpdateList() {
-	m_ui.GetServer().battles_iter->IteratorBegin();
-	while ( ! m_ui.GetServer().battles_iter->EOL() ) {
-		Battle* b = m_ui.GetServer().battles_iter->GetBattle();
+	serverSelector().GetServer().battles_iter->IteratorBegin();
+	while ( ! serverSelector().GetServer().battles_iter->EOL() ) {
+		Battle* b = serverSelector().GetServer().battles_iter->GetBattle();
 		if ( b != 0 )
 			UpdateBattle( *b );
 	}
@@ -300,31 +309,25 @@ void BattleListTab::SetFilterActiv( bool activ )
 
 void BattleListTab::OnHost( wxCommandEvent& /*unused*/ )
 {
-	if ( !m_ui.IsConnected() )
+	if ( !ui().IsConnected() )
 	{
 		wxLogWarning( _T( "Trying to host while offline" ) );
 		customMessageBoxNoModal( SL_MAIN_ICON, _( "You cannot host a game while being offline. Please connect to a lobby server." ), _( "Not Online." ), wxOK );
-		m_ui.ShowConnectWindow();
+		ui().ShowConnectWindow();
 		return;
 	}
-	if ( !m_ui.IsSpringCompatible() )
+	if ( !ui().IsSpringCompatible() )
 	{
 		wxLogWarning( _T( "Hosting is disabled due to the incompatible version " ) );
 		customMessageBoxNoModal( SL_MAIN_ICON, _( "Hosting is disabled due to the incompatible version you're using" ), _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
 		return;
 	}
-	if ( m_ui.IsSpringRunning() )
-	{
-		wxLogWarning( _T( "trying to host while spring is running" ) );
-		customMessageBoxNoModal( SL_MAIN_ICON, _( "You already are running a Spring instance, close it first in order to be able to host a new game" ), _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
-		return;
-	}
-	Battle* battle = m_ui.mw().GetJoinTab().GetCurrentBattle();
+	Battle* battle = ui().mw().GetJoinTab().GetCurrentBattle();
 	if ( battle != 0 )
 	{
-		if ( m_ui.Ask( _( "Already in a battle" ), _( "You are already in a battle.\n\nDo you want to leave current battle to start a new?" ) ) ) {
+		if ( ui().Ask( _( "Already in a battle" ), _( "You are already in a battle.\n\nDo you want to leave current battle to start a new?" ) ) ) {
 			battle->Leave();
-			m_ui.mw().GetJoinTab().LeaveCurrentBattle();
+			ui().mw().GetJoinTab().LeaveCurrentBattle();
 		}
 		else
 		{
@@ -342,7 +345,7 @@ void BattleListTab::OnHost( wxCommandEvent& /*unused*/ )
 
 		if ( bo.nattype == NAT_None && sett().GetTestHostPort() )
 		{
-			switch ( m_ui.TestHostPort( bo.port ) )
+			switch ( ui().TestHostPort( bo.port ) )
 			{
 				case Server::porttest_pass :
 					break; // success
@@ -373,7 +376,7 @@ void BattleListTab::OnHost( wxCommandEvent& /*unused*/ )
 					break;
 
 			}
-			if ( !m_ui.TestHostPort( bo.port ) )
+			if ( !ui().TestHostPort( bo.port ) )
 			{
 				wxLogWarning( _T( "hosting port %d: test unsuccessful, closing battle" ), bo.port  );
 				customMessageBoxNoModal( SL_MAIN_ICON, wxString::Format( _( "Battle not started because the port you selected (%d) is unable to recieve incoming packets\n checks your router & firewall configuration again or change port in the dialog.\n\nIf everything else fails, enable the Hole Punching NAT Traversal\n option in the hosting settings." ), bo.port ) );
@@ -428,7 +431,7 @@ void BattleListTab::OnHost( wxCommandEvent& /*unused*/ )
 		bo.isproxy = sett().GetLastHostRelayedMode();
 		if ( bo.isproxy ) bo.nattype = NAT_None;
 		bo.relayhost = sett().GetLastRelayedHost();
-		m_ui.GetServer().HostBattle( bo, sett().GetLastHostPassword() );
+		serverSelector().GetServer().HostBattle( bo, sett().GetLastHostPassword() );
 	}
 }
 
@@ -451,7 +454,7 @@ void BattleListTab::OnFilter( wxCommandEvent& /*unused*/ )
 void BattleListTab::OnFilterActiv( wxCommandEvent& /*unused*/ )
 {
 	bool active = m_filter_activ->GetValue();
-	if ( !m_ui.IsConnected() )
+	if ( !ui().IsConnected() )
 	{
 		m_filter_activ->SetValue( !active );
 		return;
@@ -474,7 +477,7 @@ void BattleListTab::OnJoin( wxCommandEvent& /*unused*/ )
 	if ( m_battle_list->GetSelectedIndex() < 0 ) return;
 
 	int id = m_battle_list->GetSelectedData()->GetBattleId();
-	DoJoin( m_ui.GetServer().battles_iter->GetBattle( id ) );
+	DoJoin( serverSelector().GetServer().battles_iter->GetBattle( id ) );
 }
 
 
@@ -489,27 +492,27 @@ void BattleListTab::OnListJoin( wxListEvent& event )
 	if ( event.GetIndex() < 0 ) return;
 
 	int id = m_battle_list->GetSelectedData()->GetBattleId();
-	DoJoin( m_ui.GetServer().battles_iter->GetBattle( id ) );
+	DoJoin( serverSelector().GetServer().battles_iter->GetBattle( id ) );
 }
 
 
 void BattleListTab::DoJoin( Battle& battle )
 {
-	if ( !m_ui.IsSpringCompatible() )
+	if ( !ui().IsSpringCompatible() )
 	{
 		wxLogWarning( _T( "trying to join battles with imcompatible spring version" ) );
 		customMessageBox( SL_MAIN_ICON, _( "Joining battles is disabled due to the incompatible spring version you're using." ), _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
 		return;
 	}
 
-	Battle* curbattle = m_ui.mw().GetJoinTab().GetCurrentBattle();
+	Battle* curbattle = ui().mw().GetJoinTab().GetCurrentBattle();
 
 	if ( curbattle != 0 && curbattle->GetID() == battle.GetID() )
 	{
-		if ( m_ui.Ask( _( "Already in this battle" ), _( "You are already in this battle.\n\nDo you want to leave it?" ) ) )
+		if ( ui().Ask( _( "Already in this battle" ), _( "You are already in this battle.\n\nDo you want to leave it?" ) ) )
 		{
 			curbattle->Leave();
-			m_ui.mw().GetJoinTab().LeaveCurrentBattle();
+			ui().mw().GetJoinTab().LeaveCurrentBattle();
 			return;
 		}
 		else
@@ -520,9 +523,9 @@ void BattleListTab::DoJoin( Battle& battle )
 
 	if ( curbattle != 0 )
 	{
-		if ( m_ui.Ask( _( "Already in another battle" ), _( "You are already in a battle.\n\nDo you want to leave your current battle and join this one?" ) ) ) {
+		if ( ui().Ask( _( "Already in another battle" ), _( "You are already in a battle.\n\nDo you want to leave your current battle and join this one?" ) ) ) {
 			curbattle->Leave();
-			m_ui.mw().GetJoinTab().LeaveCurrentBattle();
+			ui().mw().GetJoinTab().LeaveCurrentBattle();
 		}
 		else
 		{
@@ -530,13 +533,6 @@ void BattleListTab::DoJoin( Battle& battle )
 		}
 	}
 
-	if ( m_ui.IsSpringRunning() )
-	{
-		wxLogWarning( _T( "trying to join a battle while spring is running" ) );
-		customMessageBox( SL_MAIN_ICON, _( "You already are running a Spring instance, close it first in order to be able to join another battle." ), _( "Spring error" ), wxICON_EXCLAMATION | wxOK );
-		return;
-	}
-
 #ifdef NO_TORRENT_SYSTEM
 	wxString downloadProc = _( "Do you want me to take you to the download page?" );
 #else
@@ -548,7 +544,7 @@ void BattleListTab::DoJoin( Battle& battle )
 		if ( customMessageBox( SL_MAIN_ICON, _( "You need to download the mod before you can join this game.\n\n" ) + downloadProc, _( "Mod not available" ), wxYES_NO | wxICON_QUESTION ) == wxYES ) {
 			wxString modhash = battle.GetHostModHash();
 			wxString modname = battle.GetHostModName();
-			m_ui.DownloadMod ( modhash, modname );
+			ui().DownloadMod ( modhash, modname );
 		}
 		return;
 	}
@@ -558,7 +554,7 @@ void BattleListTab::DoJoin( Battle& battle )
 		if ( customMessageBox( SL_MAIN_ICON, _( "You need to download the map to be able to play in this game.\n\n" ) + downloadProc, _( "Map not available" ), wxYES_NO | wxICON_QUESTION ) == wxYES ) {
 			wxString maphash = battle.GetHostMapHash();
 			wxString mapname = battle.GetHostMapName();
-			m_ui.DownloadMap ( maphash, mapname );
+			ui().DownloadMap ( maphash, mapname );
 		}
 	}
 
@@ -588,20 +584,12 @@ void BattleListTab::OnSelect( wxListEvent& event )
 }
 
 
-void BattleListTab::OnUnitSyncReloaded()
+void BattleListTab::OnUnitsyncReloaded( GlobalEvents::GlobalEventData /*data*/ )
 {
-	if ( ! m_ui.GetServerStatus() ) {
+	if ( ! serverSelector().GetServerStatus() )
 		return;
-	}
 
-	m_ui.GetServer().battles_iter->IteratorBegin();
-	while ( ! m_ui.GetServer().battles_iter->EOL() )
-	{
-		Battle* b = m_ui.GetServer().battles_iter->GetBattle();
-		if ( b != 0 ) b->OnUnitSyncReloaded();
-	}
 	UpdateList();
-	m_minimap->UpdateMinimap();
 }
 
 void BattleListTab::UpdateHighlights()
