@@ -116,7 +116,8 @@ const MyStrings<SPRING_MAX_ALLIES> ally_choices;
 
 BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
     : wxScrolledWindow( parent, -1 ),
-	m_battle( battle )
+	m_battle( battle ),
+	m_BattleActionSink( this, &UiEvents::GetUiEventSender( UiEvents::OnBattleActionEvent ))
 {
 	GetAui().manager->AddPane( this, wxLEFT, _T( "battleroomtab" ) );
 
@@ -145,7 +146,8 @@ BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
 
 	m_player_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Players: %d" ), 0 ) );
 	m_spec_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Spectators: %d" ), 0 ) );
-	m_ally_setup_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Setup : %s" ), _T("") ) );
+	m_ally_setup_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Setup: %s" ), _T("") ) );
+	m_ok_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Unready/Unsynced: %d" ), 0 ) );
 
 	m_size_lbl = new wxStaticText( this, -1, _T( "" ) );
 	m_wind_lbl = new wxStaticText( this, -1, _T( "" ) );
@@ -302,6 +304,7 @@ BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
 	m_player_sett_sizer->Add( m_ally_setup_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
 	m_player_sett_sizer->Add( m_player_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT  | wxALL, 2 );
 	m_player_sett_sizer->Add( m_spec_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
+	m_player_sett_sizer->Add( m_ok_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
 
 	m_players_sizer->Add( m_players, 1, wxEXPAND );
 	m_players_sizer->Add( m_player_sett_sizer, 0, wxEXPAND );
@@ -476,8 +479,10 @@ void BattleRoomTab::UpdateBattleInfo( const wxString& Tag )
                 m_map_combo->SetValue( mapname );
 
 			//delete any eventual map option from the list and add options of the new map
-			for ( long i = m_map_opts_index; i < m_opts_list->GetItemCount(); i++ )
+			for ( int i = m_map_opts_index; i < m_opts_list->GetItemCount(); )
+			{
                 m_opts_list->DeleteItem( i );
+			}
 			AddMMOptionsToList( m_map_opts_index, OptionsWrapper::MapOption );
 
 			m_minimap->UpdateMinimap();
@@ -496,6 +501,13 @@ BattleroomListCtrl& BattleRoomTab::GetPlayersListCtrl()
 	return *m_players;
 }
 
+void BattleRoomTab::UpdateStatsLabels()
+{
+	m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumActivePlayers() ) );
+	m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
+	m_ok_count_lbl->SetLabel( wxString::Format( _( "Unready/Unsynced: %d" ), m_battle->GetNumActivePlayers() - m_battle->GetNumOkPlayers() ) );
+	PrintAllySetup();
+}
 
 void BattleRoomTab::UpdateUser( User& user )
 {
@@ -504,9 +516,7 @@ void BattleRoomTab::UpdateUser( User& user )
 
 	m_minimap->UpdateMinimap();
 
-	m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumUsers() - m_battle->GetSpectators() ) );
-	m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
-	PrintAllySetup();
+	UpdateStatsLabels();
 
 	if ( &user != &m_battle->GetMe() ) return;
 
@@ -664,7 +674,7 @@ void BattleRoomTab::OnAddBot( wxCommandEvent& /*unused*/ )
 		bs.aiversion = dlg.GetAIVersion();
 		bs.aitype = dlg.GetAIType();
 		bs.owner = m_battle->GetMe().GetNick();
-		ui().GetServer().AddBot( m_battle->GetBattleId(), dlg.GetNick(), bs );
+		serverSelector().GetServer().AddBot( m_battle->GetBattleId(), dlg.GetNick(), bs );
 	}
 }
 
@@ -695,7 +705,7 @@ void BattleRoomTab::OnAutoPaste( wxCommandEvent& /*unused*/ )
 {
 	if ( !m_battle ) return;
 	wxString description = wxGetTextFromUser( _( "Enter a battle description" ), _( "Set description" ), m_battle->GetDescription(), ( wxWindow* ) & ui().mw() );
-	m_autopaste_mnu->Check( description.IsEmpty() );
+	m_autopaste_mnu->Check( !description.IsEmpty() );
 	if ( !description.IsEmpty() ) m_battle->SetDescription( description );
 	sett().SetBattleLastAutoAnnounceDescription( m_autopaste_mnu->IsChecked() );
 }
@@ -844,9 +854,7 @@ void BattleRoomTab::OnUserJoined( User& user )
 	{
 		m_players->SetSelectedIndex ( m_players->GetIndexFromData( &user ) );
 	}
-	m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumUsers() - m_battle->GetSpectators() ) );
-	m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
-	PrintAllySetup();
+	UpdateStatsLabels();
 
 	UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
 			UiEvents::StatusData( wxString::Format(_("%s joined your active battle"), user.GetNick().c_str()), 1 ) );
@@ -859,9 +867,7 @@ void BattleRoomTab::OnUserLeft( User& user )
 	if ( !user.BattleStatus().IsBot() ) m_chat->Parted( user, wxEmptyString );
 	m_players->RemoveUser( user );
 
-	m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumUsers() - m_battle->GetSpectators() ) );
-	m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
-	PrintAllySetup();
+	UpdateStatsLabels();
 }
 
 
@@ -871,6 +877,7 @@ void BattleRoomTab::OnUnitsyncReloaded( GlobalEvents::GlobalEventData /*data*/ )
 	//m_minimap->UpdateMinimap();//should happen automagically now
 	ReloadMaplist();
 	UpdateBattleInfo();
+	RegenerateOptionsList();
 	m_battle->SendMyBattleStatus(); // This should reset sync status.
 }
 
@@ -878,7 +885,7 @@ long BattleRoomTab::AddMMOptionsToList( long pos, OptionsWrapper::GameOption opt
 {
 	if ( !m_battle ) return -1;
 	OptionsWrapper::wxStringTripleVec optlist = m_battle->CustomBattleOptions().getOptions( optFlag );
-	for ( OptionsWrapper::wxStringTripleVec::iterator it = optlist.begin(); it != optlist.end(); ++it )
+	for ( OptionsWrapper::wxStringTripleVec::iterator it = optlist.begin(); it != optlist.end(); it++ )
 	{
 		m_opts_list->InsertItem( pos, it->second.first );
 		wxString tag = wxString::Format( _T( "%d_" ), optFlag ) + it->first;
@@ -969,6 +976,7 @@ void BattleRoomTab::ReloadMaplist()
 
 	size_t nummaps = maplist.Count();
 	for ( size_t i = 0; i < nummaps; i++ ) m_map_combo->Insert( maplist[i], i );
+	m_map_combo->SetValue( m_battle->GetHostMapName() );
 }
 
 void BattleRoomTab::SetMap( int index )
@@ -1102,33 +1110,51 @@ void BattleRoomTab::SetBattle( Battle* battle )
 			m_autolock_chk->Disable();
 		}
 
-		long pos = 0;
-		m_opts_list->DeleteAllItems();
-		m_opts_list->InsertItem( pos, _( "Size" ) );
-		m_opt_list_map[ _( "Size" ) ] = pos++;
-		m_opts_list->InsertItem( pos , _( "Windspeed" ) );
-		m_opt_list_map[ _( "Windspeed" ) ] = pos++;
-		m_opts_list->InsertItem( pos, _( "Tidal strength" ) );
-		m_opt_list_map[ _( "Tidal strength" ) ] = pos++;
-
-		m_opts_list->InsertItem( pos++, wxEmptyString );
-		pos = AddMMOptionsToList( pos++, OptionsWrapper::EngineOption );
-		m_opts_list->InsertItem( pos++, wxEmptyString );
-		pos = AddMMOptionsToList( pos, OptionsWrapper::ModOption );
-		m_opts_list->InsertItem( pos++, wxEmptyString );
-		m_map_opts_index = pos;
-		pos = AddMMOptionsToList( pos, OptionsWrapper::MapOption );
+		RegenerateOptionsList();
 
 		ReloadMaplist();
 
 		UpdateBattleInfo( wxString::Format( _T( "%d_mapname" ), OptionsWrapper::PrivateOptions ) );
 		UpdateBattleInfo();
-		PrintAllySetup();
-		m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumUsers() - m_battle->GetSpectators() ) );
-		m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
+		UpdateStatsLabels();
 	}
 }
 
+void BattleRoomTab::RegenerateOptionsList()
+{
+	long pos = 0;
+	m_opts_list->DeleteAllItems();
+	m_opts_list->InsertItem( pos, _( "Size" ) );
+	m_opt_list_map[ _( "Size" ) ] = pos;
+	pos++;
+	m_opts_list->InsertItem( pos , _( "Windspeed" ) );
+	m_opt_list_map[ _( "Windspeed" ) ] = pos;
+	pos++;
+	m_opts_list->InsertItem( pos, _( "Tidal strength" ) );
+	m_opt_list_map[ _( "Tidal strength" ) ] = pos;
+	pos++;
+	m_opts_list->InsertItem( pos, wxEmptyString );
+	pos++;
+	pos = AddMMOptionsToList( pos, OptionsWrapper::EngineOption );
+	// AddMMOptionsToList already increments pos by itself
+	m_opts_list->InsertItem( pos, wxEmptyString );
+	pos++;
+	m_mod_opts_index = pos;
+	pos = AddMMOptionsToList( m_mod_opts_index, OptionsWrapper::ModOption );
+	// AddMMOptionsToList already increments pos by itself
+	m_opts_list->InsertItem( pos, wxEmptyString );
+	pos++;
+	m_map_opts_index = pos;
+	pos = AddMMOptionsToList( m_map_opts_index, OptionsWrapper::MapOption );
+}
+
+void BattleRoomTab::OnBattleActionEvent( UiEvents::UiEventData data )
+{
+	wxString nick = data.Count() > 0 ? data[0] : wxString(wxEmptyString);
+	wxString msg = data.Count() > 1 ? data[1] : wxString(wxEmptyString);
+	GetChatPanel().DidAction( nick, msg );
+}
+
 //void BattleRoomTab::MaximizeSizer()
 //{
 //	wxSize s = GetClientSize();
