@@ -5,6 +5,7 @@
 
 #include "mmoptionswrapper.h"
 #include "utils/isink.h"
+#include "utils/uievents.h"
 #include <map>
 
 class Ui;
@@ -89,6 +90,8 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 		void OnAutoStart( wxCommandEvent& event );
 		void OnAutoSpec( wxCommandEvent& event );
 
+		void OnBattleActionEvent( UiEvents::UiEventData data );
+
 		void OnUserJoined( User& user );
 		void OnUserLeft( User& user );
 
@@ -107,6 +110,10 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 
 		void PrintAllySetup();
 
+		void RegenerateOptionsList();
+
+		void UpdateStatsLabels();
+
 	protected:
 
 		long AddMMOptionsToList( long pos, OptionsWrapper::GameOption optFlag );
@@ -116,6 +123,7 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 		Battle* m_battle;
 		UnitSyncMap m_map;
 
+		long m_mod_opts_index;
 		long m_map_opts_index;
 
 		OptionListMap m_opt_list_map;
@@ -144,6 +152,7 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 		wxStaticText* m_player_count_lbl;
 		wxStaticText* m_spec_count_lbl;
 		wxStaticText* m_ally_setup_lbl;
+		wxStaticText* m_ok_count_lbl;
 
 		MapCtrl * m_minimap;
 
@@ -181,6 +190,8 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 
 		wxListCtrl* m_opts_list;
 
+		EventReceiverFunc<BattleRoomTab, UiEvents::UiEventData, &BattleRoomTab::OnBattleActionEvent> m_BattleActionSink;
+
 		enum {
 			BROOM_LEAVE = wxID_HIGHEST,
 			BROOM_IMREADY,
@@ -225,9 +236,9 @@ class BattleRoomTab : public wxScrolledWindow, public UnitsyncReloadedSink<Battl
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
