@@ -44,6 +44,7 @@
 #include "chatlog.h"
 #include "chatpanelmenu.h"
 #include "utils/customdialogs.h"
+#include "gui/pastedialog.h"
 #include "settings.h"
 #include "uiutils.h"
 #include "Helper/wxtextctrlhist.h"
@@ -58,10 +59,10 @@ BEGIN_EVENT_TABLE( ChatPanel, wxPanel )
 
 	EVT_TEXT_ENTER( CHAT_TEXT, ChatPanel::OnSay )
 	EVT_TEXT_PASTE( CHAT_TEXT, ChatPanel::OnPaste )
-	EVT_BUTTON( CHAT_CHAN_OPTS, ChatPanel::OnChanOpts )
-	EVT_BUTTON( CHAT_SEND, ChatPanel::OnSay )
-	EVT_TEXT_URL( CHAT_LOG,  ChatPanel::OnLinkEvent )
-	EVT_MENU ( wxID_ANY, ChatPanel::OnMenuItem )
+	EVT_BUTTON(		CHAT_CHAN_OPTS, ChatPanel::OnChanOpts )
+	EVT_BUTTON(		CHAT_SEND, ChatPanel::OnSay )
+	EVT_TEXT_URL(	CHAT_LOG,  ChatPanel::OnLinkEvent )
+	EVT_MENU (		wxID_ANY, ChatPanel::OnMenuItem )
 
 END_EVENT_TABLE()
 
@@ -280,17 +281,21 @@ void ChatPanel::CreateControls( )
 	if ( m_type == CPT_Channel ) {
 	  m_chatlog_text->SetToolTip( TE(_("right click for options (like autojoin)" ) ) );
 	  m_chan_opts_button = new wxBitmapButton(m_chat_panel, CHAT_CHAN_OPTS, icons().GetBitmap(icons().ICON_CHANNEL_OPTIONS), wxDefaultPosition , wxSize( CONTROL_HEIGHT, CONTROL_HEIGHT ) );
+	} else if ( m_type == CPT_User ) {
+		if ( m_user )
+		{
+			m_chan_opts_button = new wxBitmapButton(m_chat_panel, CHAT_CHAN_OPTS, icons().GetBitmap(icons().GetUserBattleStateIcon(m_user->GetStatus()) ), wxDefaultPosition , wxSize( CONTROL_HEIGHT, CONTROL_HEIGHT ) );
+		}
 	} else {
 	  m_chan_opts_button = 0;
 	}
 
-
 	m_say_text = new wxTextCtrlHist( textcompletiondatabase, m_chat_panel, CHAT_TEXT, _T( "" ), wxDefaultPosition, wxSize( 100, CONTROL_HEIGHT ), wxTE_PROCESS_ENTER | wxTE_PROCESS_TAB );
 	m_say_button = new wxButton( m_chat_panel, CHAT_SEND, _( "Send" ), wxDefaultPosition, wxSize( 80, CONTROL_HEIGHT ) );
 
 	// Adding elements to sizers
-	if ( m_type == CPT_Channel )
-    m_say_sizer->Add( m_chan_opts_button );
+	if ( m_type == CPT_Channel ) m_say_sizer->Add( m_chan_opts_button );
+	if ( m_type == CPT_User ) m_say_sizer->Add( m_chan_opts_button );
 	m_say_sizer->Add( m_say_text, 1, wxEXPAND );
 	m_say_sizer->Add( m_say_button );
 	m_chat_sizer->Add( m_chatlog_text, 1, wxEXPAND );
@@ -353,7 +358,7 @@ const User* ChatPanel::GetSelectedUser() const
 
 const User& ChatPanel::GetMe()  const
 {
-	return ui().GetServer().GetMe();
+	return serverSelector().GetServer().GetMe();
 }
 
 void ChatPanel::OutputLine( const wxString& message, const wxColour& col, const wxFont& fon )
@@ -400,7 +405,7 @@ void ChatPanel::OutputLine( const ChatLine& line )
 
   m_chatlog_text->SetDefaultStyle( line.chatstyle );
 
-
+#ifndef __WXOSX_COCOA__
 	if ( sett().GetUseIrcColors() )
 	{
 		wxString m1;
@@ -482,6 +487,7 @@ void ChatPanel::OutputLine( const ChatLine& line )
 
 	}
 	else
+#endif
 	{
 		m_chatlog_text->AppendText( line.chat );
 	}
@@ -516,8 +522,7 @@ void ChatPanel::OnLinkEvent( wxTextUrlEvent& event )
 void ChatPanel::OnChanOpts( wxCommandEvent& /*unused*/ )
 {
   CreatePopup();
-  if ( (m_chan_opts_button == 0) || (m_popup_menu == 0) )
-    return;
+  if ( (m_chan_opts_button == 0) || (m_popup_menu == 0) ) return;
   m_chan_opts_button->PopupMenu(m_popup_menu->GetMenu());
 }
 
@@ -773,7 +778,7 @@ void ChatPanel::SetTopic( const wxString& who, const wxString& message )
   wxStringTokenizer tkz( message, _T("\n") );
 	while ( tkz.HasMoreTokens() )
 	{
-	  wxString msg = tkz.GetNextToken().Trim();
+	  wxString msg = tkz.GetNextToken();
 	  OutputLine( _T(" ") + msg, sett().GetChatColorServer(), f );
 	}
 	OutputLine( _( " ** Set by " ) + who, sett().GetChatColorServer(), f );
@@ -781,7 +786,12 @@ void ChatPanel::SetTopic( const wxString& who, const wxString& message )
 
 void ChatPanel::UserStatusUpdated( User& who )
 {
-	if ( !m_show_nick_list || ( m_nicklist == 0 ) ) return;
+  if ( ( m_type == CPT_User ) && ( m_user == &who ) )
+  {
+	m_chan_opts_button->SetBitmapLabel( icons().GetBitmap(icons().GetUserListStateIcon(who.GetStatus(),false, who.GetBattle() != 0 ) ) );
+
+  }
+  if ( !m_show_nick_list || ( m_nicklist == 0 ) ) return;
   try
   {
 		m_nicklist->UserUpdated( who );
@@ -826,9 +836,15 @@ void ChatPanel::SetServer( Server* serv )
 	if (( serv == 0 ) && ( m_server != 0 ) ){
 	  StatusMessage( _( "Chat closed." ) );
 	  m_server->uidata.panel = 0;
+	  if ( m_nicklist ) {
+		  m_nicklist->StopTimer();
+		  m_nicklist->Clear();
+	  }
 	}
 	else if ( serv != 0 ){
 	   serv->uidata.panel = this;
+	   if ( m_nicklist )
+		   m_nicklist->StartTimer();
 	}
 	m_server = serv;
 
@@ -850,11 +866,14 @@ void ChatPanel::SetUser( const User* usr )
 	{
 	  StatusMessage( _( "Chat closed." ) );
 	  m_user->uidata.panel = 0;
+	  m_chan_opts_button->SetBitmapLabel( icons().GetBitmap(icons().ICON_EMPTY) );
 	}
 	else if ( usr != 0 ) usr->uidata.panel = this;
-
 	m_user = usr;
-
+	if ( m_user )
+	{
+		m_chan_opts_button->SetBitmapLabel( icons().GetBitmap(icons().GetUserListStateIcon(m_user->GetStatus(),false, m_user->GetBattle() != 0 ) ) );
+	}
 //	if ( m_user )
 //        m_chat_log.SetTarget( sett().GetDefaultServer(), usr->GetNick() );
 }
@@ -888,11 +907,25 @@ void ChatPanel::_SetChannel( Channel* channel )
 
 void ChatPanel::Say( const wxString& message )
 {
+	static const unsigned int flood_threshold = 5;
 	wxLogDebugFunc( message );
 	wxStringTokenizer lines( message, _T( '\n' ) );
-	if ( lines.CountTokens() > 5 ) {
-		int answer = customMessageBox ( SL_MAIN_ICON, wxString::Format( _( "Are you sure you want to paste %d lines?" ), lines.CountTokens() ), _( "Flood warning" ), wxYES_NO );
-		if ( answer == wxNO ) return;
+	if ( lines.CountTokens() > flood_threshold ) {
+		PasteDialog dl ( this, wxString::Format(
+			_( "Are you sure you want to paste %d lines?" ), lines.CountTokens() ) );
+		switch ( dl.ShowModal() ) {
+			case wxID_NO :
+				return;
+			case PasteDialog::pasteButtonReturnCode : {
+				wxString url = Paste2Pastebin( message );
+				if ( url != wxEmptyString && wxStringTokenizer( url, _T( '\n' )).CountTokens() <= flood_threshold ) {
+					Say( url );
+					return;
+				}
+			}
+			default:
+				break;
+		}
 	}
 	while ( lines.HasMoreTokens() ) {
 		wxString line = lines.GetNextToken();
