@@ -52,7 +52,7 @@ CustomVirtListCtrl<T,L>::CustomVirtListCtrl(wxWindow* parent, wxWindowID id, con
     m_bg_color( GetBackgroundColour() ),
     m_dirty_sort(false),
     m_sort_criteria_count( sort_criteria_count ),
-    m_comparator( m_sortorder, func ),
+	m_comparator( this,m_sortorder, func ),
     m_periodic_sort_timer_id( wxNewId() ),
     m_periodic_sort_timer( this, m_periodic_sort_timer_id ),
     m_periodic_sort( periodic_sort ),
@@ -69,14 +69,7 @@ CustomVirtListCtrl<T,L>::CustomVirtListCtrl(wxWindow* parent, wxWindowID id, con
     SetImageList( &icons(), wxIMAGE_LIST_STATE );
     m_sortorder = sett().GetSortOrder( name );
 
-    if ( m_periodic_sort )
-    {
-        wxTimerEvent a;
-        wxEventType evt_type = a.GetEventType();
-        Connect( m_periodic_sort_timer_id, evt_type,   wxTimerEventHandler( ThisType::OnPeriodicSort ) );
-        bool started = m_periodic_sort_timer.Start( m_periodic_sort_interval );
-        assert( started );
-    }
+	StartTimer();
 	Connect( ListctrlDoSortEventType, wxCommandEventHandler( ThisType::OnSortEvent ), NULL, this );
 
 }
@@ -89,12 +82,29 @@ void CustomVirtListCtrl<T,L>::OnQuit( GlobalEvents::GlobalEventData /*data*/ )
     Clear();
 }
 
+template < class T, class L >
+void CustomVirtListCtrl<T,L>::StartTimer()
+{
+	if ( m_periodic_sort )
+	{
+		Connect( m_periodic_sort_timer_id, wxTimerEvent().GetEventType(),   wxTimerEventHandler( ThisType::OnPeriodicSort ) );
+		bool started = m_periodic_sort_timer.Start( m_periodic_sort_interval );
+		assert( started );
+	}
+}
+
+template < class T, class L >
+void CustomVirtListCtrl<T,L>::StopTimer()
+{
+	m_periodic_sort_timer.Stop();
+	Disconnect( m_periodic_sort_timer_id, wxTimerEvent().GetEventType(),   wxTimerEventHandler( ThisType::OnPeriodicSort ) );
+}
+
 template < class T, class L >
 CustomVirtListCtrl<T,L>::~CustomVirtListCtrl()
 {
-    m_periodic_sort_timer.Stop();
-    Disconnect( m_periodic_sort_timer_id, wxTimerEvent().GetEventType(),   wxTimerEventHandler( ThisType::OnPeriodicSort ) );
-    sett().SetSortOrder( m_name, m_sortorder );
+	StopTimer();
+	sett().SetSortOrder( m_name, m_sortorder );
 }
 
 template < class T, class L >
