@@ -5,6 +5,7 @@
 #include "../uiutils.h"
 #include "../ui.h"
 #include "../settings.h"
+#include "../spring.h"
 #include "../mainwindow.h"
 #include "../images/springlobby_64.png.h"
 
@@ -41,7 +42,9 @@ NotificationManager::~NotificationManager()
 void NotificationManager::ShowNotification( UiEvents::NotficationData data )
 {
     //call this before showing everytime to accout for desktop resolution changes
-	if ( m_toasterbox ) {
+	const bool spring_running = spring().IsRunning();
+	const bool disable_if_ingame = sett().Get<bool>( _T("/GUI/NotificationPopupDisableIngame"), true );
+	if ( m_toasterbox &&  ! ( disable_if_ingame && spring_running ) ) {
 		SetPopupPosition();
 		m_toasterbox->SetPopupText( data.second, false);
 		m_toasterbox->Play();
