@@ -43,6 +43,7 @@
 #include "images/rank4.xpm"
 #include "images/rank5.xpm"
 #include "images/rank6.xpm"
+#include "images/rank7.xpm"
 #include "images/arrow_refresh.png.h"
 
 BEGIN_EVENT_TABLE( HostBattleDialog, wxDialog )
@@ -139,7 +140,7 @@ HostBattleDialog::HostBattleDialog( wxWindow* parent )
 	wxMenuItem* manual_pick_relay = new wxMenuItem( m_relayhost_list, MANUAL_PICK_HOST, _("Manually enter the manager name"), _("You'll get prompted for the exact manager name"), wxITEM_RADIO );
 	m_relayhost_list->Append( manual_pick_relay );
 	m_relayhost_list->AppendSeparator();
-	m_relayhost_array_list = ui().GetServer().GetRelayHostList();
+	m_relayhost_array_list = serverSelector().GetServer().GetRelayHostList();
 	for ( unsigned int i = 0; i < m_relayhost_array_list.GetCount(); i++ )
 	{
 		wxMenuItem* newitem = new wxMenuItem( m_relayhost_list, MANUAL_PICK_HOST + 1 + i, m_relayhost_array_list[i], _T("") , wxITEM_RADIO );
@@ -229,6 +230,12 @@ HostBattleDialog::HostBattleDialog( wxWindow* parent )
 	m_rank6_img = new wxStaticBitmap( this, wxID_ANY, wxBitmap( rank6_xpm ), wxDefaultPosition, wxSize( 16, 16 ), 0 );
 	m_rank_sizer->Add( m_rank6_img, 0, wxALL, 5 );
 
+	m_rank7_radio = new wxRadioButton( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
+	m_rank_sizer->Add( m_rank7_radio, 0, wxALL, 5 );
+
+	m_rank7_img = new wxStaticBitmap( this, wxID_ANY, wxBitmap( rank7_xpm ), wxDefaultPosition, wxSize( 16, 16 ), 0 );
+	m_rank_sizer->Add( m_rank7_img, 0, wxALL, 5 );
+
 	m_rank_box->Add( m_rank_sizer, 1, wxEXPAND, 5 );
 
 	m_pl_nat_sizer->Add( m_rank_box, 1, wxALL | wxEXPAND, 5 );
@@ -267,7 +274,6 @@ void HostBattleDialog::ReloadModList()
 	m_mod_pic->Clear();
 
 	wxArrayString modlist = usync().GetModList();
-	//modlist.Sort(CompareStringIgnoreCase);
 
 	size_t nummods = modlist.Count();
 	for ( size_t i = 0; i < nummods; i++ ) m_mod_pic->Insert( modlist[i], i );
@@ -323,6 +329,7 @@ int HostBattleDialog::GetSelectedRank()
 	if ( m_rank4_radio->GetValue() ) return 4;
 	if ( m_rank5_radio->GetValue() ) return 5;
 	if ( m_rank6_radio->GetValue() ) return 6;
+	if ( m_rank7_radio->GetValue() ) return 7;
 	return 000;
 }
 
@@ -361,5 +368,7 @@ void HostBattleDialog::OnRelayChoice( wxCommandEvent& event )
 void HostBattleDialog::OnUseRelay( wxCommandEvent&  )
 {
     m_relayed_host_pick->Show( m_relayed_host_check->IsChecked() );
+	m_port_text->Enable( !m_relayed_host_check->IsChecked() && m_nat_radios->GetSelection() == 0 );
+	m_nat_radios->Enable( !m_relayed_host_check->IsChecked() );
     Layout();
 }
