@@ -67,6 +67,8 @@ class HostBattleDialog : public wxDialog, public WindowAttributesPickle
 		wxStaticBitmap* m_rank5_img;
 		wxRadioButton* m_rank6_radio;
 		wxStaticBitmap* m_rank6_img;
+		wxRadioButton* m_rank7_radio;
+		wxStaticBitmap* m_rank7_img;
 
 		wxStaticLine* m_buttons_sep;
 		wxButton* m_cancel_btn;
@@ -101,9 +103,9 @@ class HostBattleDialog : public wxDialog, public WindowAttributesPickle
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
