@@ -137,10 +137,6 @@ class IUnitSync : public wxEvtHandler
      */
     virtual int GetModIndex( const wxString& name ) = 0;
 
-    /** Fetch the name of a mod archive by the mod index.
-     */
-    virtual wxString GetModArchive( int index ) = 0;
-
     /** Get the options for a mod by name.
      */
     virtual GameOptions GetModOptions( const wxString& name ) = 0;
@@ -148,6 +144,10 @@ class IUnitSync : public wxEvtHandler
 
     virtual wxArrayString GetModDeps( const wxString& name ) = 0;
 
+	/** Un-loads current mod in unitsync.
+	  */
+	virtual void UnSetCurrentMod() = 0;
+
     virtual int GetNumMaps() = 0;
     virtual wxArrayString GetMapList() = 0;
     virtual wxArrayString GetModValidMapList( const wxString& modname ) = 0;
@@ -158,7 +158,6 @@ class IUnitSync : public wxEvtHandler
     virtual UnitSyncMap GetMap( int index ) = 0;
     virtual UnitSyncMap GetMapEx( const wxString& mapname ) = 0;
     virtual UnitSyncMap GetMapEx( int index ) = 0;
-    virtual wxString GetMapArchive( int index ) = 0;
     virtual GameOptions GetMapOptions( const wxString& name ) = 0;
     virtual wxArrayString GetMapDeps( const wxString& name ) = 0;
 
@@ -269,9 +268,9 @@ class UnitSyncAsyncOps
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
