@@ -51,6 +51,8 @@ class MainChatTab : public wxScrolledWindow
     void LoadPerspective( const wxString& perspective_name = wxEmptyString );
     void SavePerspective( const wxString& perspective_name = wxEmptyString );
 
+	void AdvanceSelection( bool forward );
+
   protected:
 
     wxWindow* m_close_window;
@@ -74,9 +76,9 @@ class MainChatTab : public wxScrolledWindow
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
