@@ -37,6 +37,7 @@
 #include "mainwindow.h"
 #include "settings.h"
 #include "ui.h"
+#include "introguide.h"
 #include "server.h"
 #include "utils/debug.h"
 #include "utils/platform.h"
@@ -48,6 +49,7 @@
 #include "mainoptionstab.h"
 #include "iunitsync.h"
 #include "uiutils.h"
+#include "utils/misc.h"
 #include "chatpanel.h"
 #include "playback/playbacktraits.h"
 #include "playback/playbacktab.h"
@@ -105,6 +107,8 @@ BEGIN_EVENT_TABLE(MainWindow, wxFrame)
   EVT_MENU( MENU_CHANNELCHOOSER,		MainWindow::OnShowChannelChooser	)
   EVT_MENU( MENU_SCREENSHOTS,			MainWindow::OnShowScreenshots		)
   EVT_MENU( MENU_PREFERENCES,			MainWindow::OnMenuPreferences		)
+  EVT_MENU( MENU_RENAME,				MainWindow::OnMenuRename			)
+  EVT_MENU( MENU_GENERAL_HELP,			MainWindow::OnMenuFirstStart		)
 
   EVT_AUINOTEBOOK_PAGE_CHANGED( MAIN_TABS, MainWindow::OnTabsChanged )
   EVT_CLOSE( MainWindow::OnClose )
@@ -120,6 +124,7 @@ MainWindow::MainWindow( )
     m_channel_chooser(NULL),
     m_log_win(NULL)
 {
+	assert( !wxGetApp().IsSimple() );
 	SetIcon( wxIcon(springlobby_xpm) );
 
 	GetAui().manager = new AuiManagerContainer::ManagerType( this );
@@ -138,7 +143,7 @@ MainWindow::MainWindow( )
 	m_menuEdit = new wxMenu;
 	m_menuEdit->Append(MENU_AUTOJOIN_CHANNELS, _("&Autojoin channels"));
 	m_menuEdit->Append(MENU_PREFERENCES, _("&Preferences"));
-	m_settings_menu = new wxMenuItem( m_menuTools, MENU_SETTINGSPP, _("&Spring settings"), wxEmptyString, wxITEM_NORMAL );
+	m_settings_menu = new wxMenuItem( m_menuEdit, MENU_SETTINGSPP, _("&Spring settings"), wxEmptyString, wxITEM_NORMAL );
 	m_menuEdit->Append (m_settings_menu);
 
 
@@ -154,6 +159,7 @@ MainWindow::MainWindow( )
 	m_menuTools->Append(MENU_JOIN, _("&Join channel..."));
 	m_menuTools->Append(MENU_CHANNELCHOOSER, _("Channel &list"));
 	m_menuTools->Append(MENU_CHAT, _("Open private &chat..."));
+	m_menuTools->Append(MENU_RENAME, _("Change &username"));
 	m_menuTools->Append(MENU_SCREENSHOTS, _("&View screenshots"));
 	m_menuTools->AppendSeparator();
 	m_menuTools->Append(MENU_USYNC, _("&Reload maps/mods"));
@@ -166,6 +172,7 @@ MainWindow::MainWindow( )
 
 
 	wxMenu *menuHelp = new wxMenu;
+	menuHelp->Append(MENU_GENERAL_HELP, _("&Help, tutorial and FAQ"));
 	menuHelp->Append(MENU_ABOUT, _("&About"));
 	menuHelp->Append(MENU_SELECT_LOCALE, _("&Change language"));
 	menuHelp->Append(MENU_TRAC, _("&Report a bug..."));
@@ -467,7 +474,7 @@ void MainWindow::ShowChannelChooser()
         customMessageBox( SL_MAIN_ICON, _("You need to be connected to server to view channel list"), _("Not connected") );
     else {
         m_channel_chooser->ClearChannels();
-        ui().GetServer().RequestChannels();
+		serverSelector().GetServer().RequestChannels();
         m_channel_chooser->Show( true );
     }
 }
@@ -491,9 +498,9 @@ void MainWindow::OnMenuChat( wxCommandEvent& /*unused*/ )
   if ( !ui().IsConnected() ) return;
   wxString answer;
   if ( ui().AskText( _("Open Private Chat..."), _("Name of user"), answer ) ) {
-    if (ui().GetServer().UserExists( answer ) ) {
+	if (serverSelector().GetServer().UserExists( answer ) ) {
         //true puts focus on new tab
-      OpenPrivateChat( ui().GetServer().GetUser( answer ), true  );
+	  OpenPrivateChat( serverSelector().GetServer().GetUser( answer ), true  );
     }
   }
 
@@ -570,7 +577,7 @@ void MainWindow::OnShowScreenshots( wxCommandEvent& /*unused*/ )
 
 void MainWindow::OnReportBug( wxCommandEvent& /*unused*/ )
 {
-	OpenWebBrowser( _T("http://springlobby.info/projects/springlobby/issues/new") );
+	OpenWebBrowser( _T("http://projects.springlobby.info/projects/springlobby/issues/new") );
 }
 
 
@@ -661,6 +668,7 @@ void MainWindow::OnMenuLoadLayout( wxCommandEvent& /*unused*/ )
 void MainWindow::OnMenuResetLayout( wxCommandEvent& /*event*/ )
 {
 	sett().SetDoResetPerspectives( true );
+	sett().SaveSettings();
 	customMessageBoxNoModal( SL_MAIN_ICON, _("Please restart SpringLobby now"), wxEmptyString );
 }
 
@@ -710,3 +718,16 @@ void MainWindow::OnMenuPreferences( wxCommandEvent& /*event*/ )
 	m_opts_dialog = new OptionsDialog( this );
 	m_opts_dialog->Show();
 }
+
+void MainWindow::OnMenuRename( wxCommandEvent& /*event*/ )
+{
+	wxString new_username;
+	if ( ui().AskText( _("Rename"), _("Enter new nickname"), new_username ) )
+		serverSelector().GetServer().ExecuteSayCommand( _T("/rename ") + new_username );
+}
+
+void MainWindow::OnMenuFirstStart( wxCommandEvent& /*event*/ )
+{
+	IntroGuide* intro = new IntroGuide();
+	intro->Show();
+}
