@@ -80,6 +80,8 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
     void OnMenuLoadLayout( wxCommandEvent& event );
     void OnMenuResetLayout( wxCommandEvent& event );
 	void OnMenuPreferences( wxCommandEvent& event );
+	void OnMenuRename( wxCommandEvent& event );
+	void OnMenuFirstStart( wxCommandEvent& event );
     void OnUnitSyncReload( wxCommandEvent& event );
     void OnMenuAutojoinChannels( wxCommandEvent& event );
     void OnReportBug( wxCommandEvent& event );
@@ -151,11 +153,11 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
     wxLogChain* m_log_chain;
 
     enum {
-        MENU_SETTINGSPP,
         MENU_ABOUT = wxID_ABOUT,
         MENU_QUIT = wxID_EXIT,
 
         MENU_CONNECT = wxID_HIGHEST,
+		MENU_SETTINGSPP,
         MENU_DISCONNECT,
         MENU_SAVE_OPTIONS,
         MENU_JOIN,
@@ -175,7 +177,9 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
         MENU_RESET_LAYOUT,
         MENU_DEFAULT_LAYOUT,
 		MENU_SCREENSHOTS,
-		MENU_PREFERENCES
+		MENU_PREFERENCES,
+		MENU_RENAME,
+		MENU_GENERAL_HELP
     };
 
         class TabNames : public wxArrayString
@@ -235,9 +239,9 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
