@@ -320,10 +320,10 @@ bool PlaybackListFilter<PlaybackTabType>::FilterPlayback( const typename Playbac
     //Strings Plain Text & RegEx Check (Case insensitiv)
 
     //Map:
-    if ( !RefineMapname(battle.GetHostMapName() ).Upper().Contains( m_filter_map_edit->GetValue().Upper() ) && !m_filter_map_expression->Matches(RefineMapname(battle.GetHostMapName() )) ) return false;
+    if ( !battle.GetHostMapName().Upper().Contains( m_filter_map_edit->GetValue().Upper() ) && !m_filter_map_expression->Matches(battle.GetHostMapName()) ) return false;
 
     //Mod:
-    if ( !battle.GetHostModName().Upper().Contains( m_filter_mod_edit->GetValue().Upper() ) &&  !RefineModname( battle.GetHostModName() ).Upper().Contains( m_filter_mod_edit->GetValue().Upper() ) && !m_filter_mod_expression->Matches(RefineModname(battle.GetHostModName())) ) return false;
+    if ( !battle.GetHostModName().Upper().Contains( m_filter_mod_edit->GetValue().Upper() ) &&  !battle.GetHostModName().Upper().Contains( m_filter_mod_edit->GetValue().Upper() ) && !m_filter_mod_expression->Matches(battle.GetHostModName()) ) return false;
 
     if ( (!m_filter_filesize_edit->GetValue().IsEmpty() ) && !_IntCompare( playback.size , 1024 * s2l( m_filter_filesize_edit->GetValue()) , m_filter_filesize_mode) ) return false;
 
@@ -423,18 +423,18 @@ void PlaybackListFilter<PlaybackTabType>::SetDurationValue()
 {
 
     wxString dur = m_filter_duration_edit->GetValue();
-    const wxChar* sep = _T(":");
-    int sep_count = dur.Replace(sep,sep); //i know, i know
+    const wxChar* mysep = _T(":");
+    int sep_count = dur.Replace(mysep,mysep); //i know, i know
     switch ( sep_count ) {
         default:
             break;
 
         case 0: m_duration_value = s2l( dur );
             break;
-        case 1: m_duration_value = s2l( dur.AfterFirst(*sep) ) + ( s2l( dur.BeforeFirst(*sep) ) * 60 );
+        case 1: m_duration_value = s2l( dur.AfterFirst(*mysep) ) + ( s2l( dur.BeforeFirst(*mysep) ) * 60 );
             break;
-        case 2: m_duration_value = s2l( dur.AfterLast(*sep) ) + ( s2l( dur.AfterFirst(*sep).BeforeFirst(*sep) ) * 60 )
-                                    + ( s2l( dur.BeforeFirst(*sep) ) * 3600 );
+        case 2: m_duration_value = s2l( dur.AfterLast(*mysep) ) + ( s2l( dur.AfterFirst(*mysep).BeforeFirst(*mysep) ) * 60 )
+                                    + ( s2l( dur.BeforeFirst(*mysep) ) * 3600 );
             break;
 
     }
