@@ -26,12 +26,10 @@ void ReplayList::LoadPlaybacks( const wxArrayString& filenames )
     size_t size = filenames.GetCount();
     for ( size_t i = 0; i < size; ++i)
     {
-        Replay rep;
-        rep.id = i;
-				Replay& rep_ref = AddPlayback( rep ); // don't touch this reference, since elements inside this data structure are filled using pointers, adding & not fecthing the new addresses would screw up references when rep gets destroyed
+		Replay& rep_ref = AddPlayback( i ); // don't touch this reference, since elements inside this data structure are filled using pointers, adding & not fecthing the new addresses would screw up references when rep gets destroyed
         if ( !GetReplayInfos( filenames[i] , rep_ref ) )
         {
-            RemovePlayback( rep.id );
+			RemovePlayback( rep_ref.id );
             m_fails++;
         }
     }
@@ -70,20 +68,24 @@ bool ReplayList::GetReplayInfos ( const wxString& ReplayPath, Replay& ret )
     return true;
 }
 
+#define SEEK(x) if(replay.Seek(x)==wxInvalidOffset)return script;
+
 wxString ReplayList::GetScriptFromReplay ( const wxString& ReplayPath  )
 {
+
 	wxString script;
     try
     {
         wxFile replay( ReplayPath, wxFile::read );
         if ( !replay.IsOpened() ) return script;
-        replay.Seek( 20 );
+		SEEK( 20 );
         int headerSize=0 ;
         replay.Read( &headerSize, 4);
-        replay.Seek( 64 );
-        int scriptSize=0;
+		SEEK( 64 );
+		wxFileOffset scriptSize=0;
         replay.Read( &scriptSize, 4);
-        replay.Seek( headerSize );
+		scriptSize = clamp( wxFileOffset(scriptSize), wxFileOffset(0), replay.Length() );
+		SEEK( headerSize );
         std::string script_a(scriptSize,0);
         replay.Read( &script_a[0], scriptSize );
         script = TowxString( script_a ) ;//(script_a,scriptSize);
@@ -93,21 +95,22 @@ wxString ReplayList::GetScriptFromReplay ( const wxString& ReplayPath  )
     {
     }
 	return script;
+
 }
-
-
+#undef SEEK
+#define SEEK(x) if(replay.Seek(x)==wxInvalidOffset)return;
 void ReplayList::GetHeaderInfo( Replay& rep, const wxString& ReplayPath )
 {
     try
     {
         wxFile replay( ReplayPath, wxFile::read );
-        replay.Seek( 72 );
+		SEEK( 72 );
         int gametime = 0 ;
         replay.Read( &gametime, 4);
         rep.duration = gametime;
         rep.size = replay.Length();
 		wxLongLong_t unixtime = 0;
-        replay.Seek( 56 );
+		SEEK( 56 );
         replay.Read( &unixtime, 8 );
         wxDateTime dt;
         dt.Set( (time_t) unixtime );
@@ -119,3 +122,4 @@ void ReplayList::GetHeaderInfo( Replay& rep, const wxString& ReplayPath )
     catch (...){ }
 }
 
+#undef SEEK
