@@ -174,7 +174,8 @@ void ServerEvents::OnUserStatus( const wxString& nick, UserStatus status )
                 {
                     battle.SetInGame( status.in_game );
                     if ( status.in_game ) battle.StartSpring();
-                    else ui().OnBattleInfoUpdated( battle );
+					else
+						BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(user.GetBattle(),wxString()) );
                 }
             }
             }catch(...){}
@@ -351,7 +352,7 @@ void ServerEvents::OnClientBattleStatus( int battleid, const wxString& nick, Use
 }
 
 
-void ServerEvents::OnUserJoinedBattle( int battleid, const wxString& nick )
+void ServerEvents::OnUserJoinedBattle( int battleid, const wxString& nick, const wxString& userScriptPassword )
 {
     try
     {
@@ -360,6 +361,7 @@ void ServerEvents::OnUserJoinedBattle( int battleid, const wxString& nick )
         Battle& battle = m_serv.GetBattle( battleid );
 
         battle.OnUserAdded( user );
+		user.BattleStatus().scriptPassword = userScriptPassword;
         ui().OnUserJoinedBattle( battle, user );
 				try
 				{
@@ -386,6 +388,7 @@ void ServerEvents::OnUserLeftBattle( int battleid, const wxString& nick )
     {
         Battle& battle = m_serv.GetBattle( battleid );
         User& user = battle.GetUser( nick );
+		user.BattleStatus().scriptPassword.Clear();
         battle.OnUserRemoved( user );
         ui().OnUserLeftBattle( battle, user );
     }
@@ -417,7 +420,7 @@ void ServerEvents::OnBattleInfoUpdated( int battleid, int spectators, bool locke
             battle.Update( wxString::Format( _T("%d_mapname"), OptionsWrapper::PrivateOptions ) );
         }
 
-        ui().OnBattleInfoUpdated( battle );
+		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle,wxString()) );
     }
     catch (assert_exception) {}
 }
@@ -498,7 +501,7 @@ void ServerEvents::OnBattleInfoUpdated( int battleid )
     try
     {
         Battle& battle = m_serv.GetBattle( battleid );
-        ui().OnBattleInfoUpdated( battle );
+		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle,wxString()) );
     }
     catch ( assert_exception ) {}
 }
@@ -697,12 +700,13 @@ void ServerEvents::OnSaidBattle( int battleid, const wxString& nick, const wxStr
     catch (assert_exception) {}
 }
 
-void ServerEvents::OnBattleAction( int battleid, const wxString& nick, const wxString& msg )
+void ServerEvents::OnBattleAction( int /*battleid*/, const wxString& nick, const wxString& msg )
 {
     try
     {
-        Battle& battle = m_serv.GetBattle( battleid );
-        ui().OnBattleAction( battle, nick, msg );
+		UiEvents::GetUiEventSender( UiEvents::OnBattleActionEvent ).SendEvent(
+				UiEvents::OnBattleActionData( nick, msg )
+			);
     }
     catch (assert_exception) {}
 }
@@ -760,8 +764,8 @@ void ServerEvents::OnBattleRemoveBot( int battleid, const wxString& nick )
     try
     {
         Battle& battle = m_serv.GetBattle( battleid );
-				User& user = battle.GetUser( nick );
-				ui().OnUserLeftBattle( battle, user );
+		User& user = battle.GetUser( nick );
+		ui().OnUserLeftBattle( battle, user );
         battle.OnUserRemoved( user );
     }
     catch (std::runtime_error &except)
@@ -836,13 +840,20 @@ void ServerEvents::OnClientIPPort( const wxString &username, const wxString &ip,
         user.BattleStatus().udpport=udpport;
         wxLogMessage(_T("set to %s %d "),user.BattleStatus().ip.c_str(),user.BattleStatus().udpport);
 
-        if (sett().GetShowIPAddresses())ui().OnBattleAction(*m_serv.GetCurrentBattle(),username,wxString::Format(_(" has ip=%s"),ip.c_str()));
+		if (sett().GetShowIPAddresses()) {
+			UiEvents::GetUiEventSender( UiEvents::OnBattleActionEvent ).SendEvent(
+					UiEvents::OnBattleActionData( username,wxString::Format(_(" has ip=%s"),ip.c_str()) )
+				);
+		}
 
         if (m_serv.GetCurrentBattle()->GetNatType() != NAT_None && (udpport==0))
         {
             // todo: better warning message
             //something.OutputLine( _T(" ** ") + who.GetNick() + _(" does not support nat traversal! ") + GetChatTypeStr() + _T("."), sett().GetChatColorJoinPart(), sett().GetChatFont() );
-            ui().OnBattleAction(*m_serv.GetCurrentBattle(),username,_(" does not really support nat traversal"));
+			UiEvents::GetUiEventSender( UiEvents::OnBattleActionEvent ).SendEvent(
+					UiEvents::OnBattleActionData( username,_(" does not really support nat traversal") )
+				);
+
         }
         m_serv.GetCurrentBattle()->CheckBan(user);
     }
