@@ -6,7 +6,7 @@
     visit http://spring.clan-sy.com/phpbb/viewtopic.php?t=12104
     for more info/help
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
@@ -36,7 +36,7 @@
 #include "../utils/customdialogs.h"
 #include "../springunitsynclib.h"
 
-#include "Defs.hpp"
+#include "ctrlconstants.h"
 #include "se_utils.h"
 #include "../settings.h"
 #include "presets.h"
@@ -496,6 +496,16 @@ void abstract_panel::OnComboBoxChange(wxCommandEvent& event) {
 		    break;
 		}
 
+		case ID_SHADOW_CHOICES:
+		{
+			int choiceIndex = comboBox->GetCurrentSelection();
+
+			//really off = -1, off = 0, on = 1
+			//const wxString SHADOW_CHOICES[] = { _T("disabled"), _T("off"), _T("on") };
+			(intSettings)[QA_CBOX[0].key] = choiceIndex - 1;
+			break;
+		}
+
 		case ID_SIMPLE_QUAL_CBX:
 		{
 
