@@ -4,8 +4,8 @@
 #include <wx/string.h>
 #include <vector>
 
-const int CACHE_VERSION     = 10;
-const int SETTINGS_VERSION  = 21;
+const int CACHE_VERSION     = 11;
+const int SETTINGS_VERSION  = 22;
 
 const wxString DEFSETT_DEFAULT_SERVER_NAME= _T("Official server");
 const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("taspringmaster.clan-sy.com");
@@ -744,7 +744,7 @@ class Settings
     void SetMapSelectorFilterRadio( const unsigned int val );
     /**@}*/
   /* ============================================================== */
-    /** @name Relayed Hosts
+	/** @name Relay Hosts
     * @{
     */
 
@@ -753,6 +753,13 @@ class Settings
 
     /**@}*/
 
+	//!you are absolutely forbidden to use this
+	template < class T >
+	T Get( wxString setting, const T def )
+	{
+		return m_config->Read( setting, def );
+	}
+
   protected:
     bool IsSpringBin( const wxString& path );
 
@@ -779,9 +786,9 @@ Settings& sett();
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
