@@ -81,6 +81,12 @@ bool SpringUnitSync::LoadUnitSyncLib( const wxString& unitsyncloc )
 }
 
 
+static int CompareStringNoCase(const wxString& first, const wxString& second)
+{
+	return first.CmpNoCase(second);
+}
+
+
 void SpringUnitSync::PopulateArchiveList()
 {
   m_maps_list.clear();
@@ -143,6 +149,10 @@ void SpringUnitSync::PopulateArchiveList()
       wxLogError( _T("Found mod with hash collision: ") + name + _T(" hash: ") + hash );
     }
   }
+  m_unsorted_mod_array = m_mod_array;
+  m_unsorted_map_array = m_map_array;
+  m_map_array.Sort(CompareStringNoCase);
+  m_mod_array.Sort(CompareStringNoCase);
 }
 
 
@@ -206,12 +216,9 @@ wxArrayString SpringUnitSync::GetModList()
 
 int SpringUnitSync::GetModIndex( const wxString& name )
 {
-  wxLogDebugFunc( _T("name = \"") + name + _T("\"") );
-  try
-  {
-    return susynclib().GetModIndex( name );
-  } catch (...){}
-  return -1;
+	int result = m_mod_array.Index( name );
+	if ( result == wxNOT_FOUND ) result = -1;
+	return result;
 }
 
 
@@ -254,9 +261,8 @@ UnitSyncMod SpringUnitSync::GetMod( int index )
 {
   wxLogDebugFunc( _T("") );
   UnitSyncMod m;
-  susynclib().GetPrimaryModCount();
-  m.name = susynclib().GetPrimaryModName( index );
-  m.hash = susynclib().GetPrimaryModChecksum( index );
+  m.name = m_mod_array[index];
+  m.hash = m_mods_list[m.name];
 
   return m;
  }
@@ -412,7 +418,7 @@ wxArrayString SpringUnitSync::GetMapDeps( const wxString& mapname )
 	wxArrayString ret;
 	try
 	{
-		ret = susynclib().GetMapDeps( GetMapIndex( mapname ) );
+		ret = susynclib().GetMapDeps( m_unsorted_map_array.Index( mapname ) );
 	}
 	catch( unitsync_assert ) {}
 	return ret;
@@ -436,27 +442,6 @@ int SpringUnitSync::GetMapIndex( const wxString& name )
 }
 
 
-wxString SpringUnitSync::GetModArchive( int index )
-{
-  wxLogDebugFunc( _T("") );
-
-  return susynclib().GetPrimaryModArchive( index );
-}
-
-
-wxString SpringUnitSync::GetMapArchive( int index )
-{
-  wxLogDebugFunc( _T("") );
-
-  int count = susynclib().GetMapArchiveCount( index );
-
-  if ( count > 0 )
-    return susynclib().GetMapArchiveName( 0 );
-  else
-    return _T("");
-}
-
-
 GameOptions SpringUnitSync::GetModOptions( const wxString& name )
 {
   wxLogDebugFunc( name );
@@ -498,7 +483,7 @@ wxArrayString SpringUnitSync::GetModDeps( const wxString& modname )
 	wxArrayString ret;
 	try
 	{
-		ret = susynclib().GetModDeps( GetModIndex( modname ) );
+		ret = susynclib().GetModDeps( m_unsorted_mod_array.Index( modname ) );
 	}
 	catch( unitsync_assert ) {}
 	return ret;
@@ -612,6 +597,14 @@ wxArrayString SpringUnitSync::GetAIList( const wxString& modname )
   return ret;
 }
 
+void SpringUnitSync::UnSetCurrentMod()
+{
+	try
+	{
+		susynclib().UnSetCurrentMod();
+	} catch( unitsync_assert ) {}
+}
+
 wxArrayString SpringUnitSync::GetAIInfos( int index )
 {
 	wxArrayString ret;
@@ -639,7 +632,7 @@ int SpringUnitSync::GetNumUnits( const wxString& modname )
 {
   wxLogDebugFunc( _T("") );
 
-  susynclib().AddAllArchives( susynclib().GetPrimaryModArchive( susynclib().GetModIndex( modname ) ) );
+  susynclib().AddAllArchives( susynclib().GetPrimaryModArchive( m_unsorted_mod_array.Index( modname ) ) );
   susynclib().ProcessUnitsNoChecksum();
 
   return susynclib().GetUnitCount();
@@ -657,7 +650,7 @@ wxArrayString SpringUnitSync::GetUnitsList( const wxString& modname )
   } catch(...)
   {
     susynclib().SetCurrentMod( modname );
-    while ( susynclib().ProcessUnitsNoChecksum() );
+    while ( susynclib().ProcessUnitsNoChecksum() ) {}
     unsigned int unitcount = susynclib().GetUnitCount();
     for ( unsigned int i = 0; i < unitcount; i++ )
     {
@@ -818,11 +811,7 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
         info.maxWind = s2l( cache[6] );
         info.width = s2l( cache[7] );
         info.height = s2l( cache[8] );
-		#ifndef __WXMSW__
-		wxArrayString posinfo = wxStringTokenize( cache[10], _T(' '), wxTOKEN_RET_EMPTY );
-		#else
 		wxArrayString posinfo = wxStringTokenize( cache[9], _T(' '), wxTOKEN_RET_EMPTY );
-		#endif
 		for ( unsigned int i = 0; i < posinfo.GetCount(); i++)
         {
            StartPos position;
@@ -832,16 +821,12 @@ MapInfo SpringUnitSync::_GetMapInfoEx( const wxString& mapname )
         }
 
         unsigned int LineCount = cache.GetCount();
-		#ifndef __WXMSW__
-        for ( unsigned int i = 11; i < LineCount; i++ ) info.description << cache[i] << _T('\n');
-		#else
 		for ( unsigned int i = 10; i < LineCount; i++ ) info.description << cache[i] << _T('\n');
-		#endif
 
       }
       catch (...)
       {
-        info = susynclib().GetMapInfoEx( mapname, 1 );
+		info = susynclib().GetMapInfoEx( m_unsorted_map_array.Index(mapname), 1 );
 
         cache.Add ( info.author );
         cache.Add( TowxString( info.tidalStrength ) );
@@ -907,7 +892,7 @@ void SpringUnitSync::SetSpringDataPath( const wxString& path )
 
 wxString SpringUnitSync::GetFileCachePath( const wxString& name, const wxString& hash, bool IsMod )
 {
-  LOCK_UNITSYNC;
+//  LOCK_UNITSYNC;
 
   wxString ret = m_cache_path;
   if ( !name.IsEmpty() ) ret << name;
