@@ -128,9 +128,10 @@ class SpringUnitSync : public IUnitSync
     bool ModExists( const wxString& modname, const wxString& hash );
     bool ModExistsCheckHash( const wxString& hash ) const;
     UnitSyncMod GetMod( const wxString& modname );
-    UnitSyncMod GetMod( int index );
+	UnitSyncMod GetMod( int index );
+	//! this functions returns index CUSTOM ALPHBETICALLY SORTED, DO NOT USE TO ACCESS UNITSYNC DIRECTLY
+	//! use m_unsorted_mod_array for real unitsync index
     int GetModIndex( const wxString& name );
-    wxString GetModArchive( int index );
     GameOptions GetModOptions( const wxString& name );
     wxArrayString GetModDeps( const wxString& name );
 
@@ -141,10 +142,9 @@ class SpringUnitSync : public IUnitSync
     bool MapExists( const wxString& mapname, const wxString& hash );
 
     UnitSyncMap GetMap( const wxString& mapname );
-    UnitSyncMap GetMap( int index );
+	UnitSyncMap GetMap( int index );
     UnitSyncMap GetMapEx( const wxString& mapname );
-    UnitSyncMap GetMapEx( int index );
-    wxString GetMapArchive( int index );
+	UnitSyncMap GetMapEx( int index );
     GameOptions GetMapOptions( const wxString& name );
     wxArrayString GetMapDeps( const wxString& name );
 
@@ -152,7 +152,8 @@ class SpringUnitSync : public IUnitSync
 		wxString GetDefaultNick();
 		//! function to set default singplayer/replay/savegame's default nick
 		void SetDefaultNick( const wxString& nick );
-
+	//! this functions returns index CUSTOM ALPHBETICALLY SORTED, DO NOT USE TO ACCESS UNITSYNC DIRECTLY
+	//! use m_unsorted_map_array for real unitsync index
     int GetMapIndex( const wxString& name );
 
     wxArrayString GetSides( const wxString& modname  );
@@ -168,6 +169,8 @@ class SpringUnitSync : public IUnitSync
     //! function wich checks if the version returned from unitsync matches a table of supported feature
     bool VersionSupports( GameFeature feature );
 
+	void UnSetCurrentMod();
+
     wxArrayString GetAIList( const wxString& modname );
     wxArrayString GetAIInfos( int index );
     GameOptions GetAIOptions( const wxString& modname, int index );
@@ -233,8 +236,10 @@ class SpringUnitSync : public IUnitSync
     LocalArchivesVector m_maps_unchained_hash; /// mapname -> unchained hash
     LocalArchivesVector m_mods_archive_name; /// modname -> archive name
     LocalArchivesVector m_maps_archive_name; /// mapname -> archive name
-    wxArrayString m_map_array;
-    wxArrayString m_mod_array;
+	wxArrayString m_map_array; // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
+	wxArrayString m_mod_array; // this vector is CUSTOM SORTED ALPHABETICALLY, DON'T USE TO ACCESS UNITSYNC DIRECTLY
+	wxArrayString m_unsorted_map_array; // this is because unitsync doesn't have a search map index by name ..
+	wxArrayString m_unsorted_mod_array; // this isn't necessary but makes things more symmetrical :P
 
     /// caches sett().GetCachePath(), because that method calls back into
     /// susynclib(), there's a good chance main thread blocks on some
@@ -268,20 +273,10 @@ class SpringUnitSync : public IUnitSync
     bool _LoadUnitSyncLib( const wxString& unitsyncloc );
     void _FreeUnitSyncLib();
 
-    bool _ModExists( const wxString& modname );
-    UnitSyncMod _GetMod( int index );
-    wxString _GetModArchive( int index );
-
-    int _GetMapIndex( const wxString& name );
-    UnitSyncMap _GetMap( int index, bool getmapinfo = false );
-    UnitSyncMap _GetMap( const wxString& mapname, bool getmapinfo = false );
-    UnitSyncMap _GetMapEx( const wxString& mapname, bool force = false );
     MapInfo _GetMapInfoEx( const wxString& mapname );
 
     void PopulateArchiveList();
 
-    double _GetSpringVersion();
-
     wxImage _GetMapImage( const wxString& mapname, const wxString& imagename, wxImage (SpringUnitSyncLib::*loadMethod)(const wxString&) );
     wxImage _GetScaledMapImage( const wxString& mapname, wxImage (SpringUnitSync::*loadMethod)(const wxString&), int width, int height );
 
@@ -292,9 +287,9 @@ class SpringUnitSync : public IUnitSync
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
