@@ -393,17 +393,26 @@ void TorrentWrapper::SetIngameStatus( bool status )
     if ( status == ingame ) return; // no change needed
     ingame = status;
     if ( ingame )
+	{
         m_maintenance_thread.Pause();
+	}
     else
+	{
         m_maintenance_thread.Resume();
+	}
 
     try
     {
         TorrenthandleVector torrentList = m_torr->get_torrents();
         if ( ingame ) // going ingame, pause all torrents (or throttle speeds) and disable dht
         {
-            if ( sett().GetTorrentSystemSuspendMode() == 0 ) for ( unsigned int i = 0; i < torrentList.size(); i++)
-                torrentList[i].pause();
+			if ( sett().GetTorrentSystemSuspendMode() == 0 )
+			{
+				for ( unsigned int i = 0; i < torrentList.size(); i++)
+				{
+				   torrentList[i].pause();
+				}
+			}
             else
             {
                 m_torr->set_upload_rate_limit(sett().GetTorrentThrottledUploadRate() * 1024);
@@ -414,7 +423,13 @@ void TorrentWrapper::SetIngameStatus( bool status )
         else// game closed, resume all torrents (or reset normal speed) and reactivate dht
         {
             m_torr->start_dht();
-            if ( sett().GetTorrentSystemSuspendMode() == 0 ) for ( unsigned int i = 0; i < torrentList.size(); i++) torrentList[i].resume();
+			if ( sett().GetTorrentSystemSuspendMode() == 0 )
+			{
+				for ( unsigned int i = 0; i < torrentList.size(); i++)
+				{
+					torrentList[i].resume();
+				}
+			}
             else
             {
                 m_torr->set_upload_rate_limit(sett().GetTorrentUploadRate() * 1024);
@@ -467,6 +482,9 @@ void TorrentWrapper::HandleCompleted()
 				wxString source_path = TowxString( handle.save_path().string() )  +
 									   wxFileName::GetPathSeparator() +
 									   TowxString( handle.get_torrent_info().file_at( 0 ).path.string() );
+				wxString dest_path = wxPathOnly( dest_filename );
+				if ( !wxDirExists( dest_path ) )
+						wxMkdir( dest_path );
 				bool ok = wxCopyFile( source_path, dest_filename );
 				if ( !ok )
 				{
@@ -507,6 +525,7 @@ std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
     std::map<wxString,TorrentInfos> ret;
     try
     {
+		const TorrenthandleInfoMap& infomap = GetHandleInfoMap();
         TorrentInfos globalinfos;
         libtorrent::session_status session_status = m_torr->status();
         globalinfos.downloadstatus = P2P::leeching;
@@ -518,7 +537,6 @@ std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
         ret[wxString(_T("global"))] = globalinfos;
 
 		const TorrenthandleVector torrentList = m_torr->get_torrents();
-		const TorrenthandleInfoMap& infomap = GetHandleInfoMap();
 		for ( TorrenthandleInfoMap::const_iterator i = infomap.begin(); i != infomap.end(); ++i )
         {
 			try {
