@@ -20,6 +20,7 @@
 #include <wx/filename.h>
 #include <wx/app.h>
 
+#include "introguide.h"
 #include "ui.h"
 #include "tasserver.h"
 #include "settings.h"
@@ -41,6 +42,7 @@
 #include "mainchattab.h"
 #include "mainjoinbattletab.h"
 #include "mainsingleplayertab.h"
+#include "crashreport.h"
 #ifndef NO_TORRENT_SYSTEM
 #include "maintorrenttab.h"
 #include "torrentwrapper.h"
@@ -58,6 +60,9 @@
 #include "updater/versionchecker.h"
 #include "alsound.h"
 #include "globalsmanager.h"
+#include "utils/misc.h"
+
+static const unsigned int s_reconnect_delay_ms = 6000;
 
 Ui& ui()
 {
@@ -66,17 +71,53 @@ Ui& ui()
     return m_ui;
 }
 
+ServerSelector::ServerSelector()
+	: m_serv(0)
+{}
+
+bool ServerSelector::GetServerStatus() const
+{
+	return (bool)(m_serv);
+}
+
+Server& ServerSelector::GetServer()
+{
+	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
+	return *m_serv;
+}
+
+const Server& ServerSelector::GetServer() const
+{
+	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
+	return *m_serv;
+}
+
+void ServerSelector::SetCurrentServer(Server* server)
+{
+	m_serv = server;
+	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
+}
+
+ServerSelector& serverSelector()
+{
+	static LineInfo<ServerSelector> m( AT );
+	static GlobalObjectHolder<ServerSelector,LineInfo<ServerSelector> > m_selector( m );
+	return m_selector;
+}
+
 Ui::Ui() :
         m_serv(0),
         m_main_win(0),
         m_con_win(0),
         m_upd_counter_torrent(0),
         m_first_update_trigger(true),
-        m_ingame(false)
+		m_ingame(false),
+		m_battle_info_updatedSink( this, &BattleEvents::GetBattleEventSender( ( BattleEvents::BattleInfoUpdate ) ) )
 {
     m_main_win = new MainWindow( );
     CustomMessageBoxBase::setLobbypointer(m_main_win);
     m_serv = new TASServer();
+	serverSelector().SetCurrentServer( m_serv );
 }
 
 Ui::~Ui()
@@ -86,24 +127,6 @@ Ui::~Ui()
     delete m_serv;
 }
 
-Server& Ui::GetServer()
-{
-    ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
-    return *m_serv;
-}
-
-const Server& Ui::GetServer() const
-{
-    ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
-    return *m_serv;
-}
-
-bool Ui::GetServerStatus() const
-{
-    return (bool)(m_serv);
-}
-
-
 ChatPanel* Ui::GetActiveChatPanel()
 {
     return mw().GetActiveChatPanel();
@@ -190,7 +213,7 @@ void Ui::Disconnect()
     if ( m_serv != 0 )
     {
         if ( IsConnected() ) {
-            GetServer().Disconnect();
+			serverSelector().GetServer().Disconnect();
         }
     }
 }
@@ -199,6 +222,11 @@ void Ui::Disconnect()
 //! @brief Opens the accutial connection to a server.
 void Ui::DoConnect( const wxString& servername, const wxString& username, const wxString& password )
 {
+	if ( m_reconnect_delay_timer.IsRunning() ) {
+		AutocloseMessageBox m( &mw(), _("Waiting for reconnect"), wxMessageBoxCaptionStr, s_reconnect_delay_ms );
+		m.ShowModal();
+	}
+
     wxString host;
     int port;
 
@@ -210,13 +238,13 @@ void Ui::DoConnect( const wxString& servername, const wxString& username, const
 
     Disconnect();
 
-    GetServer().SetUsername( username );
-    GetServer().SetPassword( password );
+	serverSelector().GetServer().SetUsername( username );
+	serverSelector().GetServer().SetPassword( password );
 
     if ( sett().GetServerAccountSavePass( servername ) )
     {
-        if ( GetServer().IsPasswordHash(password) ) sett().SetServerAccountPass( servername, password );
-        else sett().SetServerAccountPass( servername, GetServer().GetPasswordHash( password ) );
+		if ( serverSelector().GetServer().IsPasswordHash(password) ) sett().SetServerAccountPass( servername, password );
+		else sett().SetServerAccountPass( servername, serverSelector().GetServer().GetPasswordHash( password ) );
     }
     else
     {
@@ -227,11 +255,11 @@ void Ui::DoConnect( const wxString& servername, const wxString& username, const
     host = sett().GetServerHost( servername );
     port = sett().GetServerPort( servername );
 
-    GetServer().uidata.panel = m_main_win->GetChatTab().AddChatPanel( *m_serv, servername );
-    GetServer().uidata.panel->StatusMessage( _T("Connecting to server ") + servername + _T("...") );
+	serverSelector().GetServer().uidata.panel = m_main_win->GetChatTab().AddChatPanel( *m_serv, servername );
+	serverSelector().GetServer().uidata.panel->StatusMessage( _T("Connecting to server ") + servername + _T("...") );
 
     // Connect
-    GetServer().Connect( servername, host, port );
+	serverSelector().GetServer().Connect( servername, host, port );
 
 }
 
@@ -249,7 +277,7 @@ bool Ui::DoRegister( const wxString& servername, const wxString& username, const
 
     host = sett().GetServerHost( servername );
     port = sett().GetServerPort( servername );
-    bool success = GetServer().Register( host, port, username, password,reason );
+	bool success = serverSelector().GetServer().Register( host, port, username, password,reason );
     if ( success )
     {
 			customMessageBox(SL_MAIN_ICON, _("Registration successful,\nyou should now be able to login."), _("Registration successful"), wxOK );
@@ -273,7 +301,7 @@ bool Ui::IsConnected() const
 
 void Ui::JoinChannel( const wxString& name, const wxString& password )
 {
-    if ( m_serv != 0 ) GetServer().JoinChannel( name, password );
+	if ( m_serv != 0 ) serverSelector().GetServer().JoinChannel( name, password );
 }
 
 
@@ -372,36 +400,35 @@ void Ui::ShowMessage( const wxString& heading, const wxString& message )
 bool Ui::ExecuteSayCommand( const wxString& cmd )
 {
     if ( !IsConnected() ) return false;
-    //TODO insert logic for joining multiple channels at once
-    //or remove that from "/help"
+
     if ( (cmd.BeforeFirst(' ').Lower() == _T("/join")) || (cmd.BeforeFirst(' ').Lower() == _T("/j")) )
     {
         wxString channel = cmd.AfterFirst(' ');
         wxString pass = channel.AfterFirst(' ');
         if ( !pass.IsEmpty() ) channel = channel.BeforeFirst(' ');
         if ( channel.StartsWith(_T("#")) ) channel.Remove( 0, 1 );
-        GetServer().JoinChannel( channel, pass );
+		serverSelector().GetServer().JoinChannel( channel, pass );
         return true;
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/away") )
     {
-        GetServer().GetMe().Status().away = true;
-        GetServer().GetMe().SendMyUserStatus();
+		serverSelector().GetServer().GetMe().Status().away = true;
+		serverSelector().GetServer().GetMe().SendMyUserStatus();
         return true;
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/back") )
     {
         if ( IsConnected() )
         {
-            GetServer().GetMe().Status().away = false;
-            GetServer().GetMe().SendMyUserStatus();
+			serverSelector().GetServer().GetMe().Status().away = false;
+			serverSelector().GetServer().GetMe().SendMyUserStatus();
             return true;
         }
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/ingame") )
     {
         wxString nick = cmd.AfterFirst(' ');
-        GetServer().RequestInGameTime( nick );
+		serverSelector().GetServer().RequestInGameTime( nick );
         return true;
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/help") )
@@ -414,7 +441,7 @@ bool Ui::ExecuteSayCommand( const wxString& cmd )
     {
         wxString user = cmd.AfterFirst(' ').BeforeFirst(' ');
         wxString msg = cmd.AfterFirst(' ').AfterFirst(' ');
-        GetServer().SayPrivate( user, msg );
+		serverSelector().GetServer().SayPrivate( user, msg );
         return true;
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/channels") )
@@ -444,7 +471,7 @@ void Ui::ConsoleHelp( const wxString& topic )
         panel->ClientMessage( _("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password.") );
         panel->ClientMessage( _("  \"/channels\" - Lists currently active channels.") );
         panel->ClientMessage( _("  \"/help [topic]\" - Put topic if you want to know more specific information about a command.") );
-        panel->ClientMessage( _("  \"/join channel [password] [,channel2 [password2]]\" - Joins a channel.") );
+		panel->ClientMessage( _("  \"/join channel [password]\" - Joins a channel.") );
         panel->ClientMessage( _("  \"/j\" - Alias to /join.") );
         panel->ClientMessage( _("  \"/ingame\" - Shows how much time you have in game.") );
         panel->ClientMessage( _("  \"/msg username [text]\" - Sends a private message containing text to username.") );
@@ -486,9 +513,9 @@ ChatPanel* Ui::GetChannelChatPanel( const wxString& channel )
 
 void Ui::OnUpdate( int mselapsed )
 {
-    if ( GetServerStatus() )
+	if ( serverSelector().GetServerStatus() )
     {
-        GetServer().Update( mselapsed );
+		serverSelector().GetServer().Update( mselapsed );
     }
 
     if ( m_first_update_trigger )
@@ -548,7 +575,7 @@ bool Ui::IsSpringCompatible()
 {
     sett().RefreshSpringVersionList();
     if ( sett().GetDisableSpringVersionCheck() ) return true;
-    wxString neededversion = GetServer().GetRequiredSpring();
+	wxString neededversion = serverSelector().GetServer().GetRequiredSpring();
     if ( neededversion == _T("*") ) return true; // Server accepts any version.
     else if ( neededversion.IsEmpty() ) return false;
     std::map<wxString, wxString> versionlist = sett().GetSpringVersionList();
@@ -592,6 +619,7 @@ void Ui::OnLoggedIn( )
 
 void Ui::OnDisconnected( Server& server, bool wasonline )
 {
+	m_reconnect_delay_timer.Start( s_reconnect_delay_ms, true );
     if ( m_main_win == 0 ) return;
     wxLogDebugFunc( _T("") );
     if (!&server)
@@ -627,7 +655,9 @@ void Ui::OnDisconnected( Server& server, bool wasonline )
 
 void Ui::ConnectionFailurePrompt()
 {
-	wxMessageDialog dlg( &mw(), _("A connection couldn't be established with the server\nWould you like to try again with the same server?\nNo to switch to next server in the list"), _("Connection failure"), wxYES_NO | wxCANCEL | wxNO_DEFAULT );
+	static wxMessageDialog dlg( &mw(), _("A connection couldn't be established with the server\nWould you like to try again with the same server?\nNo to switch to next server in the list"), _("Connection failure"), wxYES_NO | wxCANCEL | wxNO_DEFAULT );
+	if ( dlg.IsShown() )
+		return;
 	switch ( dlg.ShowModal() )
 	{
 		case wxID_YES: // try again with the same server/settings
@@ -827,14 +857,18 @@ void Ui::OnUserOffline( User& user )
 void Ui::OnUserStatusChanged( User& user )
 {
     if ( m_main_win == 0 ) return;
-    for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+	for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
     {
-        Channel& chan = GetServer().GetChannel( i );
+		Channel& chan = serverSelector().GetServer().GetChannel( i );
         if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
         {
             chan.uidata.panel->UserStatusUpdated( user );
         }
     }
+	if ( user.uidata.panel )
+	{
+		user.uidata.panel->UserStatusUpdated( user );
+	}
     if ( user.GetStatus().in_game ) mw().GetBattleListTab().UserUpdate( user );
     try
     {
@@ -874,7 +908,7 @@ void Ui::OnUserSaid( User& user, const wxString& message, bool fromme )
     {
         mw().OpenPrivateChat( user );
     }
-    if ( fromme ) user.uidata.panel->Said( GetServer().GetMe().GetNick(), message );
+	if ( fromme ) user.uidata.panel->Said( serverSelector().GetServer().GetMe().GetNick(), message );
     else user.uidata.panel->Said( user.GetNick(), message );
 }
 
@@ -886,9 +920,9 @@ void Ui::OnBattleOpened( IBattle& battle )
     try
     {
 			User& user = battle.GetFounder();
-			for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+			for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
 			{
-					Channel& chan = GetServer().GetChannel( i );
+					Channel& chan = serverSelector().GetServer().GetChannel( i );
 					if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
 					{
 							chan.uidata.panel->UserStatusUpdated( user );
@@ -916,9 +950,9 @@ void Ui::OnBattleClosed( IBattle& battle )
     {
         User& user = battle.GetUser( b );
         user.SetBattle(0);
-        for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+		for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
         {
-            Channel& chan = GetServer().GetChannel( i );
+			Channel& chan = serverSelector().GetServer().GetChannel( i );
             if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
             {
                 chan.uidata.panel->UserStatusUpdated( user );
@@ -938,14 +972,14 @@ void Ui::OnUserJoinedBattle( IBattle& battle, User& user )
         if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
         	 mw().GetJoinTab().GetBattleRoomTab().OnUserJoined( user );
-        	 OnBattleInfoUpdated( battle );
+			 OnBattleInfoUpdated( std::make_pair(&battle,wxString()) );
         }
     }
     catch (...){}
 
-    for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+	for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
     {
-        Channel& chan = GetServer().GetChannel( i );
+		Channel& chan = serverSelector().GetServer().GetChannel( i );
         if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
         {
             chan.uidata.panel->UserStatusUpdated( user );
@@ -965,8 +999,8 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
         if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
             mw().GetJoinTab().GetBattleRoomTab().OnUserLeft( user );
-						OnBattleInfoUpdated( battle );
-            if ( &user == &GetServer().GetMe() )
+						OnBattleInfoUpdated( std::make_pair(&battle,wxString()) );
+			if ( &user == &serverSelector().GetServer().GetMe() )
             {
                 mw().GetJoinTab().LeaveCurrentBattle();
             }
@@ -974,9 +1008,9 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
     }
     catch (...) {}
     if ( user.BattleStatus().IsBot() ) return;
-    for ( int i = 0; i < GetServer().GetNumChannels(); i++ )
+	for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
     {
-        Channel& chan = GetServer().GetChannel( i );
+		Channel& chan = serverSelector().GetServer().GetChannel( i );
         if ( ( chan.UserExists(user.GetNick()) ) && ( chan.uidata.panel != 0 ) )
         {
             chan.uidata.panel->UserStatusUpdated( user );
@@ -984,25 +1018,30 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
     }
 }
 
-void Ui::OnBattleInfoUpdated( IBattle& battle )
+void Ui::OnBattleInfoUpdated( BattleEvents::BattleEventData data )
 {
+	IBattle& battle = *data.first;
+	const wxString& Tag = data.second;
     if ( m_main_win == 0 ) return;
     mw().GetBattleListTab().UpdateBattle( battle );
     if ( mw().GetJoinTab().GetCurrentBattle() == &battle )
     {
-        mw().GetJoinTab().UpdateCurrentBattle();
+		if ( Tag.IsEmpty() )
+			mw().GetJoinTab().UpdateCurrentBattle();
+		else
+			mw().GetJoinTab().UpdateCurrentBattle( Tag );
     }
 }
 
-void Ui::OnBattleInfoUpdated( IBattle& battle, const wxString& Tag )
-{
-    if ( m_main_win == 0 ) return;
-    mw().GetBattleListTab().UpdateBattle( battle );
-    if ( mw().GetJoinTab().GetCurrentBattle() == &battle )
-    {
-        mw().GetJoinTab().UpdateCurrentBattle( Tag );
-    }
-}
+//void Ui::OnBattleInfoUpdated( IBattle& battle, const wxString& Tag )
+//{
+//    if ( m_main_win == 0 ) return;
+//    mw().GetBattleListTab().UpdateBattle( battle );
+//    if ( mw().GetJoinTab().GetCurrentBattle() == &battle )
+//    {
+//        mw().GetJoinTab().UpdateCurrentBattle( Tag );
+//    }
+//}
 
 
 void Ui::OnJoinedBattle( Battle& battle )
@@ -1034,7 +1073,7 @@ void Ui::OnUserBattleStatus( IBattle& battle, User& user )
 {
     if ( m_main_win == 0 ) return;
     mw().GetJoinTab().BattleUserUpdated( user );
-    OnBattleInfoUpdated( battle );
+	OnBattleInfoUpdated( std::make_pair(&battle,wxString()) );
 }
 
 
@@ -1070,17 +1109,6 @@ void Ui::OnSaidBattle( IBattle& /*battle*/, const wxString& nick, const wxString
     catch (...) {}
 }
 
-
-void Ui::OnBattleAction( IBattle& /*battle*/, const wxString& nick, const wxString& msg )
-{
-    if ( m_main_win == 0 ) return;
-    try
-    {
-        mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().DidAction( nick, msg );
-    }
-    catch (...){}
-}
-
 void Ui::OnSpringStarting()
 {
   m_ingame = true;
@@ -1099,9 +1127,9 @@ void Ui::OnSpringTerminated( long exit_code )
     if ( !m_serv ) return;
 
     try {
-        GetServer().GetMe().Status().in_game = false;
-        GetServer().GetMe().SendMyUserStatus();
-        Battle *battle = GetServer().GetCurrentBattle();
+		serverSelector().GetServer().GetMe().Status().in_game = false;
+		serverSelector().GetServer().GetMe().SendMyUserStatus();
+		Battle *battle = serverSelector().GetServer().GetCurrentBattle();
         if ( !battle )
             return;
         if( battle->IsFounderMe() && battle->GetAutoLockOnStart() ) {
@@ -1110,23 +1138,15 @@ void Ui::OnSpringTerminated( long exit_code )
         }
     } catch ( assert_exception ){}
 
-    if ( exit_code ) {
-//        wxDebugReportCompress report;
-//        wxString dir = sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator();
-//        wxString tmp_filename = wxPathOnly( wxFileName::CreateTempFileName(_T("dummy")) ) + wxFileName::GetPathSeparator() + _T("settings.txt");
-//        wxCopyFile( sett().GetCurrentUsedSpringConfigFilePath(), tmp_filename );
-//        report.AddFile( dir + _T("infolog.txt"), _T("Infolog") );
-//        report.AddFile( dir + _T("script.txt"), _T("Script") );
-//        report.AddFile( dir + _T("ext.txt"), _T("Infolog") );
-//        report.AddFile( dir + _T("unitsync.log"), _T("Infolog") );
-//        report.AddFile( tmp_filename, _T("Settings") );
-//        wxString info;
-//        info << wxGetOsDescription() << ( wxIsPlatform64Bit() ? _T(" 64bit\n") : _T(" 32bit\n") );
-//        report.AddText( _T("platform.txt"), info, _T("Platform") );
-//        wxDebugReportPreviewStd().Show( report );
-//        report.Process();
-        if ( customMessageBox( SL_MAIN_ICON, _T("The game has crashed.\nOpen infolog.txt?"), _T("Crash"), wxYES_NO ) == wxYES )
-            OpenFileInEditor( sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("infolog.txt") );
+	if ( sett().GetReportStats() && exit_code ) {
+		#if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
+			SpringDebugReport report;
+			if ( wxDebugReportPreviewStd().Show( report ) )
+				report.Process();
+		#else
+			if ( customMessageBox( SL_MAIN_ICON, _T("The game has crashed.\nOpen infolog.txt?"), _T("Crash"), wxYES_NO ) == wxYES )
+				OpenFileInEditor( sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("infolog.txt") );
+		#endif
     }
 }
 
@@ -1136,8 +1156,8 @@ void Ui::OnAcceptAgreement( const wxString& agreement )
     AgreementDialog dlg( m_main_win, agreement );
     if ( dlg.ShowModal() == 1 )
     {
-        GetServer().AcceptAgreement();
-        GetServer().Login();
+		serverSelector().GetServer().AcceptAgreement();
+		serverSelector().GetServer().Login();
     }
 }
 
@@ -1177,12 +1197,12 @@ bool Ui::IsThisMe(const wxString& other) const
     if (!IsConnected() || m_serv==0)
         return false;
     else
-        return ( other == GetServer().GetMe().GetNick() );
+		return ( other == serverSelector().GetServer().GetMe().GetNick() );
 }
 
 int Ui::TestHostPort( unsigned int port ) const
 {
-    return GetServer().TestOpenPort( port );
+	return serverSelector().GetServer().TestOpenPort( port );
 }
 
 void Ui::ReloadPresetList()
@@ -1238,23 +1258,22 @@ void Ui::FirstRunWelcome()
 #endif
 
         wxLogMessage( _T("first time startup"));
-        wxMessageBox(_("Hi ") + wxGetUserName() + _(",\nIt looks like this is your first time using SpringLobby. I have guessed a configuration that I think will work for you but you should review it, especially the Spring configuration. \n\nWhen you are done you can go to the File menu, connect to a server, and enjoy a nice game of Spring :)"), _("Welcome"),
+		wxMessageBox(_("Hi ") + wxGetUserName() + _(",\nIt looks like this is your first time using SpringLobby. I have guessed a configuration that I think will work for you but you should review it, especially the Spring configuration."), _("Welcome"),
                      wxOK | wxICON_INFORMATION, &mw() );
 
+		IntroGuide* intro = new IntroGuide();
+		intro->Show();
 
-        customMessageBoxNoModal(SL_MAIN_ICON, _("By default SpringLobby reports some usage statistics.\nYou can disable that on options tab --> General."),_("Notice"),wxOK );
-
-
-                // copy uikeys.txt
-                wxPathList pl;
-                pl.AddEnvList( _T("%ProgramFiles%") );
-                pl.AddEnvList( _T("XDG_DATA_DIRS") );
-                pl = sett().GetAdditionalSearchPaths( pl );
-                wxString uikeyslocation = pl.FindValidPath( _T("uikeys.txt") );
-                if ( !uikeyslocation.IsEmpty() )
-                {
-                    wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
-                }
+		// copy uikeys.txt
+		wxPathList pl;
+		pl.AddEnvList( _T("%ProgramFiles%") );
+		pl.AddEnvList( _T("XDG_DATA_DIRS") );
+		pl = sett().GetAdditionalSearchPaths( pl );
+		wxString uikeyslocation = pl.FindValidPath( _T("uikeys.txt") );
+		if ( !uikeyslocation.IsEmpty() )
+		{
+			wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
+		}
 
     #ifdef __WXMSW__
         if ( TASClientPresent() &&
@@ -1276,6 +1295,9 @@ void Ui::FirstRunWelcome()
 
 void Ui::CheckForUpdates()
 {
+	wxString t = _T("SpringLobby test\njfrepojeivnpenver\nwvpreivienrio\npwoewnpfwpnef\njcwoejfwp");
+	Paste2Pastebin( t );
+	return;
     wxString latestVersion = GetLatestVersion();
 
     if (latestVersion == _T("-1"))
