@@ -24,7 +24,9 @@ typedef int AlertEventType;
 
 extern const wxEventType torrentSystemStatusUpdateEvt;
 
+#include "utils/battleevents.h"
 #include <wx/string.h>
+#include <wx/timer.h>
 
 //! @brief UI main class
 class Ui
@@ -39,9 +41,6 @@ class Ui
         SavegamePlayback
     };
 
-    Server& GetServer();
-    const Server& GetServer() const;
-    bool    GetServerStatus() const;
     ChatPanel* GetActiveChatPanel();
     ChatPanel* GetChannelChatPanel( const wxString& channel );
 
@@ -113,8 +112,8 @@ class Ui
     void OnBattleClosed( IBattle& battle );
     void OnUserJoinedBattle( IBattle& battle, User& user );
     void OnUserLeftBattle( IBattle& battle, User& user );
-    void OnBattleInfoUpdated( IBattle& battle );
-    void OnBattleInfoUpdated( IBattle& battle, const wxString& Tag );
+	void OnBattleInfoUpdated( BattleEvents::BattleEventData data );
+//    void OnBattleInfoUpdated( IBattle& battle, const wxString& Tag );
     void OnBattleStarted( Battle& battle );
 
     void OnJoinedBattle( Battle& battle );
@@ -123,7 +122,7 @@ class Ui
     void OnRequestBattleStatus( IBattle& battle );
 
     void OnSaidBattle( IBattle& battle, const wxString& nick, const wxString& msg );
-    void OnBattleAction( IBattle& battle, const wxString& nick, const wxString& msg );
+//    void OnBattleAction( IBattle& battle, const wxString& nick, const wxString& msg );
 
     void OnSpringStarting();
     void OnSpringTerminated( long exit_code );
@@ -155,6 +154,7 @@ class Ui
     Server* m_serv;
     MainWindow* m_main_win;
     ConnectWindow* m_con_win;
+	wxTimer m_reconnect_delay_timer;
 
     wxString m_last_used_backup_server;
 
@@ -164,6 +164,9 @@ class Ui
 
     bool m_ingame;
 
+	EventReceiverFunc<Ui, BattleEvents::BattleEventData, &Ui::OnBattleInfoUpdated>
+		m_battle_info_updatedSink;
+
     //! does actual work, called from downloadmap/mod
     void DownloadFileP2P( const wxString& name );
 	void DownloadFileWebsite( const wxString& name );
@@ -175,14 +178,29 @@ class Ui
 
 Ui& ui();
 
+class ServerSelector;
+ServerSelector& serverSelector();
+
+#include "globalsmanager.h"
+class ServerSelector {
+public:
+	Server& GetServer();
+	const Server& GetServer() const;
+	void SetCurrentServer(Server* server);
+	bool    GetServerStatus() const;
+protected:
+	ServerSelector();
+	Server* m_serv;
+	friend class GlobalObjectHolder<ServerSelector, LineInfo<ServerSelector> >;
+};
 
 #endif // SPRINGLOBBY_HEADERGUARD_UI_H
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
